#........................................................................................................
### ~~ R CODE FOR EXCESS MORTALITY SIMULATION RELATED TO SOMALIA DEATH TOLL ESTIMATION (2010-2012) ~~ ###

# Written by Francesco Checchi, LSHTM (April 2013)
# francesco.checchi@lshtm.ac.uk 


#..........................................................................................
### Preparatory

rm(list=ls(all=TRUE))

# working directory
setwd("C:/Users/Francesco/Desktop/Analysis")
#setwd("H:/Francesco/LSHTM academic 2009-/FSNAU Somalia/Analysis") #office

# required packages
library(lattice)
library(lme4)
library(reshape2)
library(ggplot2)

# read data
strata <- read.csv("analysis_strata.csv")
tst <- read.csv("tseries_strata.pop3.csv") # strata time series
year <- seq(2006, 2012, 1) #sequence of years
month <- seq(1, 12, 1) #sequence of months
dat <- read.csv("survey_metadata_analysed.csv") # survey metadata after analysis
eth.origins <- read.csv("ethiopia_origins.csv") # origins of Ethiopia refugees, by month
ken.origins <- read.csv("kenya_origins.csv") # origins of Kenya refugees (Polonsky - overall)

# Set correct reference levels for some variables to be used in model building
dat[, "m.rate_incidents_lag3_cat"] <- ifelse(dat[, "m.rate_incidents_lag3_cat"] == "2-Jan", "1-2", as.character(dat[, "m.rate_incidents_lag3_cat"]) )

dat <- within(dat, m.outbreak_cat <- relevel(as.factor(m.outbreak_cat), ref = "no outbreaks"))

dat[, "m.AToTw_lag2_cat"] <- factor(dat[, "m.AToTw_lag2_cat"] , levels = c("25,000+", "20,000-24,999", "15,000-19,999", "10,000-14,999", "0-9999") ) 

dat[, "wfp_present_lag2"] <- factor(dat[, "wfp_present_lag2"] , levels = c("yes", "no") ) 
	

# CDR extrapolation model
	fit.cdr.extr <- lm(cdr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + as.factor(livelihood)  +
						   as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat),
						   data = dat, weights = cdr_survey_weight1
						   )


# U5DR extrapolation model
	fit.u5dr.extr <- lm(u5dr.bct ~ as.factor(m.location) + as.factor(m.rate_incidents_lag3_cat) + as.factor(livelihood)  +
						   as.factor(m.outbreak_cat) + wfp_present_lag2 * as.factor(m.AToTw_lag2_cat),
						   data = dat, weights = u5dr_survey_weight1
						   )

# function to back-transform fitted values from Box-Cox metric (useful for later prediction and model comparison)
f.bctback <- function(f.tr, f.untr, f.lambda) {
	gm <- exp(mean(log(f.untr))) # geometric mean of dependent variable
			
	return ( (f.tr * (f.lambda * gm^(f.lambda - 1) ) + 1 )^(1/f.lambda) )

	}

lambda = 0.4						   

# Empirical distribution of data on proportion of the population under 5y in Somalia
#NO LONGER USED prop.u5.som <- 	subset(dat, is.finite(prop_hh_u5) & location1 == "Somalia" )[, "prop_hh_u5"]

# Empirical distribution of data on proportion of the population under 5y in Ethiopia camps
prop.u5.eth <- 	c(0.258, 0.256)

# Empirical distribution of data on proportion of the population under 5y in Kenya camps
prop.u5.ken <- 	c(0.316, 0.244)
	

#.........................................................................................
### Code for step 1 - draw random crude death rate

## For months with direct estimate

# calculate log death rates
tst[, "ln_cdr1"] <- log(tst[, "cdr_est_model1"] / 10000)
tst[, "ln_cdr2"] <- log(tst[, "cdr_est_model2"] / 10000)
tst[, "ln_cdr3"] <- log(tst[, "cdr_est_model3"] / 10000)
tst[, "ln_cdr4"] <- log(tst[, "cdr_est_model4"] / 10000)
tst[, "ln_cdr5"] <- log(tst[, "cdr_est_model5"] / 10000)
tst[, "ln_cdr6"] <- log(tst[, "cdr_est_model6"] / 10000)

tst[, "ln_u5dr1"] <- log(tst[, "u5dr_est_model1"] / 10000)
tst[, "ln_u5dr2"] <- log(tst[, "u5dr_est_model2"] / 10000)
tst[, "ln_u5dr3"] <- log(tst[, "u5dr_est_model3"] / 10000)
tst[, "ln_u5dr4"] <- log(tst[, "u5dr_est_model4"] / 10000)
tst[, "ln_u5dr5"] <- log(tst[, "u5dr_est_model5"] / 10000)
tst[, "ln_u5dr6"] <- log(tst[, "u5dr_est_model6"] / 10000)


## For months without direct estimate

# create model categorical variables
	# location
	tst[, "m.location"] <- ifelse(tst[, "location"] %in% c("Somaliland", "Puntland") , "Sland-Ptland", "Somalia")

	# conflict incident rate with lag 3 months
	tst[, "rate_incidents_lag3"] <- NA

	for (i in 4:nrow(tst) ) {

		if (tst[i, "stratum"] == tst[i-3, "stratum"])  {tst[i, "rate_incidents_lag3"] =  tst[i-3, "rate_incidents"] }
		
	}

	tst[, "m.rate_incidents_lag3_cat"] <- cut(tst[, "rate_incidents_lag3"], c(0, 0.000001, 1, 2, max(tst[, "rate_incidents_lag3"], na.rm=TRUE ) ) ,
											  include.lowest=TRUE, labels = c("0", "0-1", "1-2", "2+") )
	
	# outbreaks occurrence
	tst[, "outbreak"] <- ifelse(is.na(tst[, "outbreak"])==TRUE, "unknown", as.character(tst[, "outbreak"]) )
	
	f.outbreak <- function(f.tst) {
		
		if (f.tst[["outbreak"]] == "unknown") return (NA)
		if (f.tst[["outbreak"]] == "none") return ("no outbreaks")
		if (f.tst[["outbreak"]] != "none" & grepl(",", f.tst[["outbreak"]]) == FALSE ) return ("1 outbreak")
		if (f.tst[["outbreak"]] != "none" & grepl(",", f.tst[["outbreak"]]) == TRUE ) return ("2+ outbreaks")
	
	}
	tst[, "m.outbreak_cat"] <- apply(tst, 1, f.outbreak)

	# WFP presence with lag 2 months
	tst[, "wfp_present_lag2"] <- NA

	for (i in 3:nrow(tst) ) {

		if (tst[i, "stratum"] == tst[i-2, "stratum"])  {tst[i, "wfp_present_lag2"] =  tst[i-2, "wfp_present"] }
		
	}
	
	tst[, "wfp_present_lag2"] <- ifelse(tst[, "wfp_present_lag2"]==1, "no", "yes")
	
	# AToTw category with lag 2 months
	tst[, "AToTw_lag2"] <- NA

	for (i in 3:nrow(tst) ) {

		if (tst[i, "stratum"] == tst[i-2, "stratum"])  {tst[i, "AToTw_lag2"] =  tst[i-2, "AToTw"] }
		
	}
	
	tst[, "m.AToTw_lag2_cat"] <- cut( tst[, "AToTw_lag2"] , c(0, 10000, 15000, 20000, 25000, max(tst[, "AToTw_lag2"], na.rm=TRUE) ), 
	                                  include.lowest=TRUE, labels = c("0-9999", "10,000-14,999", "15,000-19,999", "20,000-24,999", "25,000+") )


### Write file

# sort time series again
tst <- tst[order(tst[, "stratum"], tst[, "tm"]), ]

# write file
write.csv(tst, "tseries_strata.pop3.csv", row.names=FALSE)
	
	
# stratum-months within analysis period in Somalia
tst.analysis.som <- subset(tst, period==1 & location=="Somalia")
									  
# use predictive models to generate CDR and U5DR predictions and their standard errors
tst.analysis.som[, "cdr.bct.pred"] <- predict(fit.cdr.extr, tst.analysis.som, se.fit=TRUE)[1]
tst.analysis.som[, "cdr.bct.pred.se"] <- predict(fit.cdr.extr, tst.analysis.som, se.fit=TRUE)[2]

tst.analysis.som[, "u5dr.bct.pred"] <- predict(fit.u5dr.extr, tst.analysis.som, se.fit=TRUE)[1]
tst.analysis.som[, "u5dr.bct.pred.se"] <- predict(fit.u5dr.extr, tst.analysis.som, se.fit=TRUE)[2]

# untransform predictions
tst.analysis.som[, "cdr.pred"] <- sapply(tst.analysis.som$cdr.bct.pred, f.bctback, as.numeric(dat$cdr_est_model), lambda)
tst.analysis.som[, "u5dr.pred"] <- sapply(tst.analysis.som$u5dr.bct.pred, f.bctback, as.numeric(dat$u5dr_est_model), lambda)


## Generate random death rate value

# function to sample a random death rate value for every stratum-month
f.crude <- function(f.tst, f.rate, f.dat, f.lambda, f.bctback) {

	#if there is at least one survey covering the stratum-month...
	if (is.na(f.tst[[paste(f.rate, "_survey_prob1", sep="")]])==FALSE ) {

		# select one survey at random for stratum-month
		rand_id <- sample(c(1:6), 1, prob = c(as.numeric(f.tst[[paste(f.rate, "_survey_prob1", sep="")]]), as.numeric(f.tst[[paste(f.rate, "_survey_prob2", sep="")]]), 
		                                      as.numeric(f.tst[[paste(f.rate, "_survey_prob3", sep="")]]), as.numeric(f.tst[[paste(f.rate, "_survey_prob4", sep="")]]), 
											  as.numeric(f.tst[[paste(f.rate, "_survey_prob5", sep="")]]), as.numeric(f.tst[[paste(f.rate, "_survey_prob6", sep="")]]) )
				         )
		
		# sample from log point estimate and standard error of selected survey
		return ( 10000 * exp (rnorm(1, as.numeric(f.tst[[paste("ln_", f.rate, rand_id, sep="")]]) , as.numeric(f.tst[[paste("ln_", f.rate, "_se_adj", rand_id, sep="")]]) ) ) )
	}

	# otherwise if there is no survey covering the stratum-month...	
	else {

		#sample from uncertainty distribution of model prediction
		rand <- rnorm(1, as.numeric(f.tst[[paste(f.rate, ".bct.pred", sep="")]]) , as.numeric(f.tst[[paste(f.rate, ".bct.pred.se", sep="")]]) )

		# return untransformed rate
		return (f.bctback(rand, f.dat[, paste(f.rate, "_est_model", sep="")], f.lambda) )
	}
		
}



#.........................................................................................
### Code for step 2 - draw random baseline death rate

## Method 1 (ToT)
base_tot <-subset(dat, baseline_tot=="yes" & m.location=="Somalia")
base_tot[, "ln_cdr"] <- log(base_tot[, "cdr_est_model"] / 10000)
base_tot[, "ln_u5dr"] <- log(base_tot[, "u5dr_est_model"] / 10000)

f.base1 <- function(f.tst, f.base_tot, f.liv.wt, f.rate) {

	# select a survey at random based on livelihood of stratum and survey weight 1 * livelihood importance weight
	sprobs <- ifelse(as.character(f.base_tot[, "livelihood"]) == as.character(f.tst[["livelihood"]]),
	                                                       as.numeric(f.base_tot[, paste(f.rate, "_survey_weight1", sep="")]) * f.liv.wt,
	                                                       as.numeric(f.base_tot[, paste(f.rate, "_survey_weight1", sep="")]) )

	id.rand <- sample(1:nrow(f.base_tot), 1, replace = TRUE, prob = sprobs ) 
													   
	# generate random death rate value
	return (10000 * exp(rnorm(1, as.numeric(f.base_tot[id.rand, paste("ln_", f.rate, sep="")] ),
	                             as.numeric(f.base_tot[id.rand, paste("ln_", f.rate, "_se", sep="")] ) ) ) )

	}

	
## Method 2 (IPC)
base_ipc <-subset(dat, baseline_ipc=="yes" & m.location=="Somalia")
base_ipc[, "ln_cdr"] <- log(base_ipc[, "cdr_est_model"] / 10000)
base_ipc[, "ln_u5dr"] <- log(base_ipc[, "u5dr_est_model"] / 10000)

f.base2 <- function(f.base_ipc, f.rate) {

	# select a survey at random based on survey weight 1
	id.rand <- sample(1:nrow(f.base_ipc), 1, replace = TRUE, prob = as.numeric(f.base_ipc[, paste(f.rate, "_survey_weight1", sep="")] ) )
	
	# generate random death rate value
	return (10000 * exp(rnorm(1, as.numeric(f.base_ipc[id.rand, paste("ln_", f.rate, sep="")] ),
	                             as.numeric(f.base_ipc[id.rand, paste("ln_", f.rate, "_se", sep="")] ) ) ) )

	}

	

## Method 3 (model)
base_model <- tst.analysis.som #carbon copy of strata time series

#artificially modify some variables to take their reference levels in the model:
base_model[, "m.outbreak_cat"] <- "no outbreaks"

base_model <- subset(base_model, select=-m.AToTw_lag2_cat)
		
		out <-c()
		
		for (i in c(unique(as.character(tst.analysis.som[, "stratum"])) ) ) {

			st <- subset(strata, stratum==i)$tm_crisis_start
			
			x <- as.character( subset(tst, stratum==i)[(st-3):(st-1), "m.AToTw_lag2_cat"] )
			
			out <-c(out, unique(x)[which.max(tabulate(match(x, unique(x))))] )
		}	

out <- cbind( unique(as.character(tst.analysis.som[, "stratum"])) , out )
colnames(out) <- c("stratum", "m.AToTw_lag2_cat")		

base_model <- merge(base_model, out, by="stratum", all.x=TRUE)


#base_model[, "m.AToTw_lag2_cat"] <- "25,000+"
#base_model[, "wfp_present_lag2"] <- "yes"  # not done as WFP would likely have pulled out irrespective of food security emergency

#predict baseline CDR and U5DR based on this fictitious dataset
tst.analysis.som[, "cdr.bct.base"] <- predict(fit.cdr.extr, base_model, se.fit=TRUE)[1]
tst.analysis.som[, "cdr.bct.base.se"] <- predict(fit.cdr.extr, base_model, se.fit=TRUE)[2]

tst.analysis.som[, "u5dr.bct.base"] <- predict(fit.u5dr.extr, base_model, se.fit=TRUE)[1]
tst.analysis.som[, "u5dr.bct.base.se"] <- predict(fit.u5dr.extr, base_model, se.fit=TRUE)[2]

# untransform predictions
tst.analysis.som[, "cdr.base.pred"] <- sapply(tst.analysis.som$cdr.bct.base, f.bctback, as.numeric(dat$cdr_est_model), lambda)
tst.analysis.som[, "u5dr.base.pred"] <- sapply(tst.analysis.som$u5dr.bct.base, f.bctback, as.numeric(dat$u5dr_est_model), lambda)

# function to sample a random baseline death rate value for every stratum-month
f.base3 <- function(f.tst, f.rate, f.dat, f.lambda, f.bctback) {

	#sample from uncertainty distribution of model prediction
	rand <- rnorm(1, as.numeric(f.tst[[paste(f.rate, ".bct.base", sep="")]]) , as.numeric(f.tst[[paste(f.rate, ".bct.base.se", sep="")]]) )

	# return untransformed rate
	return (f.bctback(rand, as.numeric(f.dat[, paste(f.rate, "_est_model", sep="")]), f.lambda) )
		
}

# modification to sample a random baseline death rate value for every stratum-month for Ethiopia
	# function that attributes sampling weights to estimated method 3 baseline CDR and CDR, based on where refugees originated on any given month
	f.base3.eth.wts <- function(f.tst.analysis.som, f.eth.origins, f.strata) {
		out <- subset(f.eth.origins, tm == as.numeric(f.tst.analysis.som[["tm"]]) )[, "other"] /  nrow(subset(f.strata, region!="Gedo" & region!="Bakool" & region!="Bay" & region!="Banadir") )
		if (as.character(f.tst.analysis.som[["region"]] ) == "Gedo") out <- subset(f.eth.origins, tm == as.numeric(f.tst.analysis.som[["tm"]]) )[, "Gedo"] / nrow(subset(f.strata, region=="Gedo") )
		if (as.character(f.tst.analysis.som[["region"]] ) == "Bay") out <- subset(f.eth.origins, tm == as.numeric(f.tst.analysis.som[["tm"]]) )[, "Bay"]  / nrow(subset(f.strata, region=="Bay") )
		if (as.character(f.tst.analysis.som[["region"]] ) == "Bakool") out <- subset(f.eth.origins, tm == as.numeric(f.tst.analysis.som[["tm"]]) )[, "Bakool"]  / nrow(subset(f.strata, region=="Bakool") )
		if (as.character(f.tst.analysis.som[["region"]] ) == "Banadir") out <- subset(f.eth.origins, tm == as.numeric(f.tst.analysis.som[["tm"]]) )[, "Banadir"]  / nrow(subset(f.strata, region=="Banadir") )
		
		return(out)
	
		}
	# apply function to attribute sampling weights for Ethiopia baseline method 3
	tst.analysis.som[, "eth.wt"] <- as.numeric(apply(tst.analysis.som, 1, f.base3.eth.wts, eth.origins, strata) )
	
		# sort time series again
		tst.analysis.som <- tst.analysis.som[order(tst.analysis.som[, "stratum"], tst.analysis.som[, "tm"]), ]
	
		# add weights for months of April and May 2010 (assume they are the same as June 2010)
		for (i in 1:nrow(tst.analysis.som) ) {

			if (tst.analysis.som[i, "tm"] == 54 ) {
	
				tst.analysis.som[i-1, "eth.wt"] = tst.analysis.som[i, "eth.wt"]
				tst.analysis.som[i-2, "eth.wt"] = tst.analysis.som[i, "eth.wt"]
	
			}
		}

		
	# function to sample a random baseline CDR or U5DR for baseline method 3 for the Ethiopia camps
	f.base3.eth <- function(f.tst.analysis.eth, f.rate, f.tst.analysis.som, f.dat, f.lambda, f.bctback) {
		
		# determine month and select somalia data for that month
		f.som <- subset(f.tst.analysis.som, tm == as.numeric( f.tst.analysis.eth[["tm"]] ) )
	
		# sample one stratum for this month based on Ethiopia-specific weights (refugee origin)
		f.str <- sample(as.character (f.som[, "stratum"] ), 1, replace=TRUE, prob=as.numeric(f.som[, "eth.wt"]) )
		f.som <- subset(f.som, stratum==as.character(f.str) )
		
		# sample from uncertainty distribution of model prediction
		rand <- rnorm(1, as.numeric(f.som[[paste(f.rate, ".bct.base", sep="")]]) , as.numeric(f.som[[paste(f.rate, ".bct.base.se", sep="")]]) )

		# return untransformed rate
		return (f.bctback(rand, as.numeric(f.dat[, paste(f.rate, "_est_model", sep="")]), f.lambda) )
	
		}

		
# modification to sample a random baseline death rate value for every stratum-month for Kenya
	# attributing sampling weights to estimated method 3 baseline CDR and CDR, based on where refugees originated (as per Polonsky)
	tst.analysis.som <- merge(tst.analysis.som, ken.origins, by="region", all.x=TRUE)
	tst.analysis.som[, "ken.wt"] <- ifelse(is.na(tst.analysis.som[, "ken.wt"])==TRUE, subset(ken.origins, region=="other")[, "ken.wt"],
	                                       tst.analysis.som[, "ken.wt"])

	# sort time series again
		tst.analysis.som <- tst.analysis.som[order(tst.analysis.som[, "stratum"], tst.analysis.som[, "tm"]), ]	

	# function to sample a random baseline CDR or U5DR for baseline method 3 for the Ethiopia camps
	f.base3.ken <- function(f.tst.analysis.ken, f.rate, f.tst.analysis.som, f.dat, f.lambda, f.bctback) {
		
		# determine month and select Somalia data for that month
		f.som <- subset(f.tst.analysis.som, tm == as.numeric( f.tst.analysis.ken[["tm"]] ) )
	
		# sample one stratum for this month based on Kenya-specific weights (refugee origin)
		f.str <- sample(as.character (f.som[, "stratum"] ), 1, replace=TRUE, prob=as.numeric(f.som[, "ken.wt"]) )
		f.som <- subset(f.som, stratum==as.character(f.str) )
		
		# sample from uncertainty distribution of model prediction
		rand <- rnorm(1, as.numeric(f.som[[paste(f.rate, ".bct.base", sep="")]]) , as.numeric(f.som[[paste(f.rate, ".bct.base.se", sep="")]]) )

		# return untransformed rate
		return (f.bctback(rand, as.numeric(f.dat[, paste(f.rate, "_est_model", sep="")]), f.lambda) )
	
		}
		
# save Somalia time series
write.csv(tst.analysis.som, "tst.analysis.som.pop3.csv")

	
# visualise predicted CDR and U5DR in each stratum

	# set general plot parameters
	par(mar=c(5, 4, 2, 2) + 0.1)
	windowsFonts(Calibri=windowsFont("Calibri"))
	par(family="Calibri")
	
	# plot u5dr in each stratum one by one
		for (i in c(unique(as.character(tst.analysis.som[, "stratum"])) ) ) {

			dat.graph <- subset(tst.analysis.som, stratum==i)
			plot(dat.graph$tm, dat.graph$u5dr.pred, axes=F, ylim=c(0, 15), xlab="", ylab="", type="l", col="darkred", lty=1,
				 main=dat.graph[1, "stratum"], xlim=c(6, 79) , lwd=1)
			lines(dat.graph$tm, dat.graph$u5dr.base.pred, type="l", col="cadetblue4", lty=1, lwd=1 )
			axis(2, ylim=c(0, 15), lwd=1)
			mtext(2, text="deaths per 10,000 person-days", line=2)

			# add horizontal ablines
			abline(h = seq(0, 6, 0.1), lty=3, col="grey")

			axis(1, at=seq(7, 79 , by=1), col="black", labels=FALSE)
	
			# add x axis labels
			lablist <- seq(7, 79, by=2)
			text(seq(7, 79 , by=2),  par("usr")[3] + 0.2 , labels = lablist, srt = 0, pos = 1, cex=0.8 , xpd = TRUE)
			mtext("month", side=1, col="black", line=3.3)	

			# add ablines for each month
			abline(v=seq(7, 79, 1), lty=3, col="grey")
			abline(v=seq(7, 79, 12), lty=3, col="black")
	
			Sys.sleep(1)
		}


#.........................................................................................
### Somalia estimation

	# number of simulation runs
	runs <- 10000

	# simulation with baseline method 1, population dataset being analysed / Somalia
	sim.cdr.base1.pop3 <- replicate(runs, {
			(apply(tst.analysis.som, 1, f.crude, "cdr", dat, lambda, f.bctback)  - apply(tst.analysis.som, 1, f.base1, base_tot, 5, "cdr") ) * tst.analysis.som[, "pop3"] * 30.42 / 10000
		} )

	sim.cdr.base1.pop3 <- cbind(tst.analysis.som[, c("stratum", "region", "livelihood", "tm", "y", "m", "pop3")] , sim.cdr.base1.pop3 )	
	write.csv(sim.cdr.base1.pop3, "somalia_sim.cdr.base1.pop3.csv")

	sim.u5dr.base1.pop3 <- replicate(runs, {
			(apply(tst.analysis.som, 1, f.crude, "u5dr", dat, lambda, f.bctback) - apply(tst.analysis.som, 1, f.base1, base_tot, 5, "u5dr") ) * tst.analysis.som[, "pop3.u5"] * 30.42 / 10000
		} )

	sim.u5dr.base1.pop3 <- cbind(tst.analysis.som[, c("stratum", "region", "livelihood", "tm", "y", "m", "pop3.u5")] , sim.u5dr.base1.pop3 )	
	write.csv(sim.u5dr.base1.pop3, "somalia_sim.u5dr.base1.pop3.csv")

	# simulation with baseline method 2, population dataset being analysed / Somalia
	sim.cdr.base2.pop3 <- replicate(runs, {
			(apply(tst.analysis.som, 1, f.crude, "cdr", dat, lambda, f.bctback)  - replicate(nrow(tst.analysis.som), {f.base2(base_ipc, "cdr") } ) ) * tst.analysis.som[, "pop3"] * 30.42 / 10000
		} )

	sim.cdr.base2.pop3 <- cbind(tst.analysis.som[, c("stratum", "region", "livelihood", "tm", "y", "m", "pop3")] , sim.cdr.base2.pop3 )	
	write.csv(sim.cdr.base2.pop3, "somalia_sim.cdr.base2.pop3.csv")
		
	sim.u5dr.base2.pop3 <- replicate(runs, {
			(apply(tst.analysis.som, 1, f.crude, "u5dr", dat, lambda, f.bctback) - replicate(nrow(tst.analysis.som), {f.base2(base_ipc, "u5dr") } ) ) * tst.analysis.som[, "pop3.u5"] * 30.42 / 10000
		} )

	sim.u5dr.base2.pop3 <- cbind(tst.analysis.som[, c("stratum", "region", "livelihood", "tm", "y", "m", "pop3.u5")] , sim.u5dr.base2.pop3 )	
	write.csv(sim.u5dr.base2.pop3, "somalia_sim.u5dr.base2.pop3.csv")

	# simulation with baseline method 3, population dataset being analysed / Somalia	
	sim.cdr.base3.pop3 <- replicate(runs, {
			(apply(tst.analysis.som, 1, f.crude, "cdr", dat, lambda, f.bctback)  - apply(tst.analysis.som, 1, f.base3, "cdr", dat, lambda, f.bctback) ) * tst.analysis.som[, "pop3"] * 30.42 / 10000
		} )		

	sim.cdr.base3.pop3 <- cbind(tst.analysis.som[, c("stratum", "region", "livelihood", "tm", "y", "m", "pop3")] , sim.cdr.base3.pop3 )	
	write.csv(sim.cdr.base3.pop3, "somalia_sim.cdr.base3.pop3.csv")
		
	sim.u5dr.base3.pop3 <- replicate(runs, {
			(apply(tst.analysis.som, 1, f.crude, "u5dr", dat, lambda, f.bctback)  - apply(tst.analysis.som, 1, f.base3, "u5dr", dat, lambda, f.bctback) ) * tst.analysis.som[, "pop3.u5"] * 30.42 / 10000
		} )		

	sim.u5dr.base3.pop3 <- cbind(tst.analysis.som[, c("stratum", "region", "livelihood", "tm", "y", "m", "pop3.u5")] , sim.u5dr.base3.pop3 )	
	write.csv(sim.u5dr.base3.pop3, "somalia_sim.u5dr.base3.pop3.csv")
	
	
	
# create result tables

	# by stratum
	tab <- data.frame(unique(na.omit(sim.cdr.base1.pop3)[, c("region", "livelihood")]))
	
	out <-subset(sim.cdr.base1.pop3, tm>57 & tm<77)
	out <-aggregate(na.omit(out)[, 8:(runs+7)], list(na.omit(out)$stratum), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50, 0.025, 0.975)) ) } ) )
	out <- round(out/100, 0)*100
	out <- paste(out[, 1], " (", out[, 2], " to ", out[, 3], ")", sep="")
	tab[, "base1"] <- out

	out <-subset(sim.u5dr.base1.pop3, tm>57 & tm<77)	
	out <-aggregate(na.omit(out)[, 8:(runs+7)], list(na.omit(out)$stratum), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50, 0.025, 0.975)) ) } ) )
	out <- round(out/100, 0)*100
	out <- paste(out[, 1], " (", out[, 2], " to ", out[, 3], ")", sep="")
	tab[, "base1.u5"] <- out

	out <-subset(sim.cdr.base2.pop3, tm>57 & tm<77)	
	out <-aggregate(na.omit(out)[, 8:(runs+7)], list(na.omit(out)$stratum), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50, 0.025, 0.975)) ) } ) )
	out <- round(out/100, 0)*100
	out <- paste(out[, 1], " (", out[, 2], " to ", out[, 3], ")", sep="")
	tab[, "base2"] <- out

	out <-subset(sim.u5dr.base2.pop3, tm>57 & tm<77)	
	out <-aggregate(na.omit(out)[, 8:(runs+7)], list(na.omit(out)$stratum), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50, 0.025, 0.975)) ) } ) )
	out <- round(out/100, 0)*100
	out <- paste(out[, 1], " (", out[, 2], " to ", out[, 3], ")", sep="")
	tab[, "base2.u5"] <- out

	out <-subset(sim.cdr.base3.pop3, tm>57 & tm<77)	
	out <-aggregate(na.omit(out)[, 8:(runs+7)], list(na.omit(out)$stratum), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50, 0.025, 0.975)) ) } ) )
	out <- round(out/100, 0)*100
	out <- paste(out[, 1], " (", out[, 2], " to ", out[, 3], ")", sep="")
	tab[, "base3"] <- out

	out <-subset(sim.u5dr.base3.pop3, tm>57 & tm<77)	
	out <-aggregate(na.omit(out)[, 8:(runs+7)], list(na.omit(out)$stratum), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50, 0.025, 0.975)) ) } ) )
	out <- round(out/100, 0)*100
	out <- paste(out[, 1], " (", out[, 2], " to ", out[, 3], ")", sep="")
	tab[, "base3.u5"] <- out
	
	tab[nrow(tab)+1, 1] <- NA

	out <-subset(sim.cdr.base1.pop3, tm>57 & tm<77)	
	out <- round(quantile(colSums(na.omit(out)[, 8:(runs+7)]) , c(0.50, 0.025, 0.975)) / 100, 0) * 100 
	out <- paste(out[1], " (", out[2], " to ", out[3], ")", sep="")
	tab[nrow(tab), "base1"] <- out

	out <-subset(sim.u5dr.base1.pop3, tm>57 & tm<77)
	out <- round(quantile(colSums(na.omit(out)[, 8:(runs+7)]) , c(0.50, 0.025, 0.975)) / 100, 0) * 100 
	out <- paste(out[1], " (", out[2], " to ", out[3], ")", sep="")
	tab[nrow(tab), "base1.u5"] <- out
	
	out <-subset(sim.cdr.base2.pop3, tm>57 & tm<77)
	out <- round(quantile(colSums(na.omit(out)[, 8:(runs+7)]) , c(0.50, 0.025, 0.975)) / 100, 0) * 100 
	out <- paste(out[1], " (", out[2], " to ", out[3], ")", sep="")
	tab[nrow(tab), "base2"] <- out

	out <-subset(sim.u5dr.base2.pop3, tm>57 & tm<77)
	out <- round(quantile(colSums(na.omit(out)[, 8:(runs+7)]) , c(0.50, 0.025, 0.975)) / 100, 0) * 100 
	out <- paste(out[1], " (", out[2], " to ", out[3], ")", sep="")
	tab[nrow(tab), "base2.u5"] <- out

	out <-subset(sim.cdr.base3.pop3, tm>57 & tm<77)
	out <- round(quantile(colSums(na.omit(out)[, 8:(runs+7)]) , c(0.50, 0.025, 0.975)) / 100, 0) * 100 
	out <- paste(out[1], " (", out[2], " to ", out[3], ")", sep="")
	tab[nrow(tab), "base3"] <- out

	out <-subset(sim.u5dr.base3.pop3, tm>57 & tm<77)
	out <- round(quantile(colSums(na.omit(out)[, 8:(runs+7)]) , c(0.50, 0.025, 0.975)) / 100, 0) * 100 
	out <- paste(out[1], " (", out[2], " to ", out[3], ")", sep="")
	tab[nrow(tab), "base3.u5"] <- out

	write.csv(tab, "Somalia_toll_stratum.pop3.csv", row.names=FALSE)
	
	
	# by region	

	tab <- data.frame(unique(na.omit(sim.cdr.base1.pop3)[, "region"]))
	
	out <-subset(sim.cdr.base1.pop3, tm>57 & tm<77)
	out <-aggregate(na.omit(out)[, 8:(runs+7)], list(na.omit(out)$region), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50, 0.025, 0.975)) ) } ) )
	out <- round(out/100, 0)*100
	out <- paste(out[, 1], " (", out[, 2], " to ", out[, 3], ")", sep="")
	tab[, "base1"] <- out

	out <-subset(sim.u5dr.base1.pop3, tm>57 & tm<77)	
	out <-aggregate(na.omit(out)[, 8:(runs+7)], list(na.omit(out)$region), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50, 0.025, 0.975)) ) } ) )
	out <- round(out/100, 0)*100
	out <- paste(out[, 1], " (", out[, 2], " to ", out[, 3], ")", sep="")
	tab[, "base1.u5"] <- out

	out <-subset(sim.cdr.base2.pop3, tm>57 & tm<77)	
	out <-aggregate(na.omit(out)[, 8:(runs+7)], list(na.omit(out)$region), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50, 0.025, 0.975)) ) } ) )
	out <- round(out/100, 0)*100
	out <- paste(out[, 1], " (", out[, 2], " to ", out[, 3], ")", sep="")
	tab[, "base2"] <- out

	out <-subset(sim.u5dr.base2.pop3, tm>57 & tm<77)	
	out <-aggregate(na.omit(out)[, 8:(runs+7)], list(na.omit(out)$region), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50, 0.025, 0.975)) ) } ) )
	out <- round(out/100, 0)*100
	out <- paste(out[, 1], " (", out[, 2], " to ", out[, 3], ")", sep="")
	tab[, "base2.u5"] <- out

	out <-subset(sim.cdr.base3.pop3, tm>57 & tm<77)	
	out <-aggregate(na.omit(out)[, 8:(runs+7)], list(na.omit(out)$region), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50, 0.025, 0.975)) ) } ) )
	out <- round(out/100, 0)*100
	out <- paste(out[, 1], " (", out[, 2], " to ", out[, 3], ")", sep="")
	tab[, "base3"] <- out

	out <-subset(sim.u5dr.base3.pop3, tm>57 & tm<77)	
	out <-aggregate(na.omit(out)[, 8:(runs+7)], list(na.omit(out)$region), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50, 0.025, 0.975)) ) } ) )
	out <- round(out/100, 0)*100
	out <- paste(out[, 1], " (", out[, 2], " to ", out[, 3], ")", sep="")
	tab[, "base3.u5"] <- out
	
	tab[nrow(tab)+1, 1] <- NA

	out <-subset(sim.cdr.base1.pop3, tm>57 & tm<77)	
	out <- round(quantile(colSums(na.omit(out)[, 8:(runs+7)]) , c(0.50, 0.025, 0.975)) / 100, 0) * 100 
	out <- paste(out[1], " (", out[2], " to ", out[3], ")", sep="")
	tab[nrow(tab), "base1"] <- out

	out <-subset(sim.u5dr.base1.pop3, tm>57 & tm<77)
	out <- round(quantile(colSums(na.omit(out)[, 8:(runs+7)]) , c(0.50, 0.025, 0.975)) / 100, 0) * 100 
	out <- paste(out[1], " (", out[2], " to ", out[3], ")", sep="")
	tab[nrow(tab), "base1.u5"] <- out
	
	out <-subset(sim.cdr.base2.pop3, tm>57 & tm<77)
	out <- round(quantile(colSums(na.omit(out)[, 8:(runs+7)]) , c(0.50, 0.025, 0.975)) / 100, 0) * 100 
	out <- paste(out[1], " (", out[2], " to ", out[3], ")", sep="")
	tab[nrow(tab), "base2"] <- out

	out <-subset(sim.u5dr.base2.pop3, tm>57 & tm<77)
	out <- round(quantile(colSums(na.omit(out)[, 8:(runs+7)]) , c(0.50, 0.025, 0.975)) / 100, 0) * 100 
	out <- paste(out[1], " (", out[2], " to ", out[3], ")", sep="")
	tab[nrow(tab), "base2.u5"] <- out

	out <-subset(sim.cdr.base3.pop3, tm>57 & tm<77)
	out <- round(quantile(colSums(na.omit(out)[, 8:(runs+7)]) , c(0.50, 0.025, 0.975)) / 100, 0) * 100 
	out <- paste(out[1], " (", out[2], " to ", out[3], ")", sep="")
	tab[nrow(tab), "base3"] <- out

	out <-subset(sim.u5dr.base3.pop3, tm>57 & tm<77)
	out <- round(quantile(colSums(na.omit(out)[, 8:(runs+7)]) , c(0.50, 0.025, 0.975)) / 100, 0) * 100 
	out <- paste(out[1], " (", out[2], " to ", out[3], ")", sep="")
	tab[nrow(tab), "base3.u5"] <- out

	write.csv(tab, "Somalia_toll_region.pop3.csv", row.names=FALSE)
		
	
	# by livelihood

	tab <- data.frame(unique(na.omit(sim.cdr.base1.pop3)[, "livelihood"]))
	
	out <-subset(sim.cdr.base1.pop3, tm>57 & tm<77)
	out <-aggregate(na.omit(out)[, 8:(runs+7)], list(na.omit(out)$livelihood), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50, 0.025, 0.975)) ) } ) )
	out <- round(out/100, 0)*100
	out <- paste(out[, 1], " (", out[, 2], " to ", out[, 3], ")", sep="")
	tab[, "base1"] <- out

	out <-subset(sim.u5dr.base1.pop3, tm>57 & tm<77)	
	out <-aggregate(na.omit(out)[, 8:(runs+7)], list(na.omit(out)$livelihood), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50, 0.025, 0.975)) ) } ) )
	out <- round(out/100, 0)*100
	out <- paste(out[, 1], " (", out[, 2], " to ", out[, 3], ")", sep="")
	tab[, "base1.u5"] <- out

	out <-subset(sim.cdr.base2.pop3, tm>57 & tm<77)	
	out <-aggregate(na.omit(out)[, 8:(runs+7)], list(na.omit(out)$livelihood), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50, 0.025, 0.975)) ) } ) )
	out <- round(out/100, 0)*100
	out <- paste(out[, 1], " (", out[, 2], " to ", out[, 3], ")", sep="")
	tab[, "base2"] <- out

	out <-subset(sim.u5dr.base2.pop3, tm>57 & tm<77)	
	out <-aggregate(na.omit(out)[, 8:(runs+7)], list(na.omit(out)$livelihood), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50, 0.025, 0.975)) ) } ) )
	out <- round(out/100, 0)*100
	out <- paste(out[, 1], " (", out[, 2], " to ", out[, 3], ")", sep="")
	tab[, "base2.u5"] <- out

	out <-subset(sim.cdr.base3.pop3, tm>57 & tm<77)	
	out <-aggregate(na.omit(out)[, 8:(runs+7)], list(na.omit(out)$livelihood), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50, 0.025, 0.975)) ) } ) )
	out <- round(out/100, 0)*100
	out <- paste(out[, 1], " (", out[, 2], " to ", out[, 3], ")", sep="")
	tab[, "base3"] <- out

	out <-subset(sim.u5dr.base3.pop3, tm>57 & tm<77)	
	out <-aggregate(na.omit(out)[, 8:(runs+7)], list(na.omit(out)$livelihood), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50, 0.025, 0.975)) ) } ) )
	out <- round(out/100, 0)*100
	out <- paste(out[, 1], " (", out[, 2], " to ", out[, 3], ")", sep="")
	tab[, "base3.u5"] <- out
	
	tab[nrow(tab)+1, 1] <- NA

	out <-subset(sim.cdr.base1.pop3, tm>57 & tm<77)	
	out <- round(quantile(colSums(na.omit(out)[, 8:(runs+7)]) , c(0.50, 0.025, 0.975)) / 100, 0) * 100 
	out <- paste(out[1], " (", out[2], " to ", out[3], ")", sep="")
	tab[nrow(tab), "base1"] <- out

	out <-subset(sim.u5dr.base1.pop3, tm>57 & tm<77)
	out <- round(quantile(colSums(na.omit(out)[, 8:(runs+7)]) , c(0.50, 0.025, 0.975)) / 100, 0) * 100 
	out <- paste(out[1], " (", out[2], " to ", out[3], ")", sep="")
	tab[nrow(tab), "base1.u5"] <- out
	
	out <-subset(sim.cdr.base2.pop3, tm>57 & tm<77)
	out <- round(quantile(colSums(na.omit(out)[, 8:(runs+7)]) , c(0.50, 0.025, 0.975)) / 100, 0) * 100 
	out <- paste(out[1], " (", out[2], " to ", out[3], ")", sep="")
	tab[nrow(tab), "base2"] <- out

	out <-subset(sim.u5dr.base2.pop3, tm>57 & tm<77)
	out <- round(quantile(colSums(na.omit(out)[, 8:(runs+7)]) , c(0.50, 0.025, 0.975)) / 100, 0) * 100 
	out <- paste(out[1], " (", out[2], " to ", out[3], ")", sep="")
	tab[nrow(tab), "base2.u5"] <- out

	out <-subset(sim.cdr.base3.pop3, tm>57 & tm<77)
	out <- round(quantile(colSums(na.omit(out)[, 8:(runs+7)]) , c(0.50, 0.025, 0.975)) / 100, 0) * 100 
	out <- paste(out[1], " (", out[2], " to ", out[3], ")", sep="")
	tab[nrow(tab), "base3"] <- out

	out <-subset(sim.u5dr.base3.pop3, tm>57 & tm<77)
	out <- round(quantile(colSums(na.omit(out)[, 8:(runs+7)]) , c(0.50, 0.025, 0.975)) / 100, 0) * 100 
	out <- paste(out[1], " (", out[2], " to ", out[3], ")", sep="")
	tab[nrow(tab), "base3.u5"] <- out

	write.csv(tab, "Somalia_toll_livelihood.pop3.csv", row.names=FALSE)
	
	
	# by whether estimate was direct or indirect

	out <- subset(sim.cdr.base1.pop3, tm>57 & tm<77)
	out <- merge(out, tst.analysis.som[, c("stratum", "tm", "coverage")], by=c("stratum", "tm"), all.x=TRUE)
	out <-aggregate(na.omit(out)[, 8:(runs+7)], list(na.omit(out)$coverage), FUN=sum, na.rm=TRUE)	
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } ) )
	print("base1 cdr: indirect = ")
	out[1]
	print("base1 cdr: direct = ")
	out[2]	
	print("base1 cdr: percent direct: ")
	out[2] / (out[1] + out[2])

	out <- subset(sim.cdr.base2.pop3, tm>57 & tm<77)
	out <- merge(out, tst.analysis.som[, c("stratum", "tm", "coverage")], by=c("stratum", "tm"), all.x=TRUE)
	out <-aggregate(na.omit(out)[, 8:(runs+7)], list(na.omit(out)$coverage), FUN=sum, na.rm=TRUE)	
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } ) )
	print("base2 cdr: indirect = ")
	out[1]
	print("base2 cdr: direct = ")
	out[2]	
	print("base2 cdr: percent direct: ")
	out[2] / (out[1] + out[2])

	out <- subset(sim.cdr.base3.pop3, tm>57 & tm<77)
	out <- merge(out, tst.analysis.som[, c("stratum", "tm", "coverage")], by=c("stratum", "tm"), all.x=TRUE)
	out <-aggregate(na.omit(out)[, 8:(runs+7)], list(na.omit(out)$coverage), FUN=sum, na.rm=TRUE)	
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } ) )
	print("base3 cdr: indirect = ")
	out[1]
	print("base3 cdr: direct = ")
	out[2]	
	print("base3 cdr: percent direct: ")
	out[2] / (out[1] + out[2])

			
	
	# by month
	tab <- data.frame(unique(na.omit(sim.cdr.base1.pop3)[, c("y", "m")]))
	tab <- tab[order(tab[, "y"], tab[, "m"]), ]
	
	out <-aggregate(na.omit(sim.cdr.base1.pop3)[, 8:(runs+7)], list(na.omit(sim.cdr.base1.pop3)$tm), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50, 0.025, 0.975)) ) } ) )
	out <- round(out/100, 0)*100
	out <- paste(out[, 1], " (", out[, 2], " to ", out[, 3], ")", sep="")
	tab[, "base1"] <- out
	
	out <-aggregate(na.omit(sim.u5dr.base1.pop3)[, 8:(runs+7)], list(na.omit(sim.u5dr.base1.pop3)$tm), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50, 0.025, 0.975)) ) } ) )
	out <- round(out/100, 0)*100
	out <- paste(out[, 1], " (", out[, 2], " to ", out[, 3], ")", sep="")
	tab[, "base1.u5"] <- out
		
	out <-aggregate(na.omit(sim.cdr.base2.pop3)[, 8:(runs+7)], list(na.omit(sim.cdr.base2.pop3)$tm), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50, 0.025, 0.975)) ) } ) )
	out <- round(out/100, 0)*100
	out <- paste(out[, 1], " (", out[, 2], " to ", out[, 3], ")", sep="")
	tab[, "base2"] <- out
	
	out <-aggregate(na.omit(sim.u5dr.base2.pop3)[, 8:(runs+7)], list(na.omit(sim.u5dr.base2.pop3)$tm), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50, 0.025, 0.975)) ) } ) )
	out <- round(out/100, 0)*100
	out <- paste(out[, 1], " (", out[, 2], " to ", out[, 3], ")", sep="")
	tab[, "base2.u5"] <- out
		
	out <-aggregate(na.omit(sim.cdr.base3.pop3)[, 8:(runs+7)], list(na.omit(sim.cdr.base3.pop3)$tm), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50, 0.025, 0.975)) ) } ) )
	out <- round(out/100, 0)*100
	out <- paste(out[, 1], " (", out[, 2], " to ", out[, 3], ")", sep="")
	tab[, "base3"] <- out
	
	out <-aggregate(na.omit(sim.u5dr.base3.pop3)[, 8:(runs+7)], list(na.omit(sim.u5dr.base3.pop3)$tm), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50, 0.025, 0.975)) ) } ) )
	out <- round(out/100, 0)*100
	out <- paste(out[, 1], " (", out[, 2], " to ", out[, 3], ")", sep="")
	tab[, "base3.u5"] <- out
	
	tab[nrow(tab)+1, 1] <- NA
	
	out <- round(quantile(colSums(na.omit(sim.cdr.base1.pop3)[, 8:(runs+7)]) , c(0.50, 0.025, 0.975)) / 100, 0) * 100 
	out <- paste(out[1], " (", out[2], " to ", out[3], ")", sep="")
	tab[nrow(tab), "base1"] <- out

	out <- round(quantile(colSums(na.omit(sim.u5dr.base1.pop3)[, 8:(runs+7)]) , c(0.50, 0.025, 0.975)) / 100, 0) * 100 
	out <- paste(out[1], " (", out[2], " to ", out[3], ")", sep="")
	tab[nrow(tab), "base1.u5"] <- out

	out <- round(quantile(colSums(na.omit(sim.cdr.base2.pop3)[, 8:(runs+7)]) , c(0.50, 0.025, 0.975)) / 100, 0) * 100 
	out <- paste(out[1], " (", out[2], " to ", out[3], ")", sep="")
	tab[nrow(tab), "base2"] <- out

	out <- round(quantile(colSums(na.omit(sim.u5dr.base2.pop3)[, 8:(runs+7)]) , c(0.50, 0.025, 0.975)) / 100, 0) * 100 
	out <- paste(out[1], " (", out[2], " to ", out[3], ")", sep="")
	tab[nrow(tab), "base2.u5"] <- out

	out <- round(quantile(colSums(na.omit(sim.cdr.base3.pop3)[, 8:(runs+7)]) , c(0.50, 0.025, 0.975)) / 100, 0) * 100 
	out <- paste(out[1], " (", out[2], " to ", out[3], ")", sep="")
	tab[nrow(tab), "base3"] <- out

	out <- round(quantile(colSums(na.omit(sim.u5dr.base3.pop3)[, 8:(runs+7)]) , c(0.50, 0.025, 0.975)) / 100, 0) * 100 
	out <- paste(out[1], " (", out[2], " to ", out[3], ")", sep="")
	tab[nrow(tab), "base3.u5"] <- out

	write.csv(tab, "Somalia_toll_month.pop3.csv", row.names=FALSE)
	
		# graph of all-age excess deaths by month
		
			# create table
			tab <- data.frame(unique(na.omit(sim.cdr.base1.pop3)[, c("y", "m")]))
			tab <- tab[order(tab[, "y"], tab[, "m"]), ]
			tab[, "tm"] <- sort(unique(na.omit(sim.cdr.base1.pop3)[, "tm"]))

			out <-aggregate(na.omit(sim.cdr.base1.pop3)[, 8:(runs+7)], list(na.omit(sim.cdr.base1.pop3)$tm), FUN=sum, na.rm=TRUE)
			out <- apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } )			
			tab[, "base1"] <- out

			out <-aggregate(na.omit(sim.cdr.base2.pop3)[, 8:(runs+7)], list(na.omit(sim.cdr.base2.pop3)$tm), FUN=sum, na.rm=TRUE)
			out <- apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } )			
			tab[, "base2"] <- out

			out <-aggregate(na.omit(sim.cdr.base3.pop3)[, 8:(runs+7)], list(na.omit(sim.cdr.base3.pop3)$tm), FUN=sum, na.rm=TRUE)
			out <- apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } )			
			tab[, "base3"] <- out

					
				# set general plot parameters
				par(mar=c(5, 6, 2, 2) + 0.1, cex=1.5)
				windowsFonts(Calibri=windowsFont("Calibri"))
				par(family="Calibri")
				
				# plot base1
				plot(tab[, "tm"], tab[, "base1"], xaxt="n", ylim=c(min(tab[, c("base1", "base2", "base3")]), max(tab[, c("base1", "base2", "base3")])),
					 xlab="", ylab="", type="o", col="darkred", lty=1, lwd=1, las=2, pch=1, yaxp=c(-5000, 30000, 7) )
				mtext("monthly estimated excess deaths (all ages)", side=2, col="black", line=5, cex=1.5)
				
				# plot base2
				lines(tab[, "tm"], tab[, "base2"], type="o", col="cadetblue4", lty=1, lwd=1, pch=4 )
				
				# plot base3
				lines(tab[, "tm"], tab[, "base3"], type="o", col="mediumpurple3", lty=1, lwd=1, pch=2 )
		
				# add x axis labels
				axis(1, at=seq(min(tab$tm), max(tab$tm), by=3), col="black", labels=FALSE )

				lablist.m <- c("Apr", "Jul", "Oct",  "Jan", "Apr", "Jul", "Oct", "Jan", "Apr", "Jul")
				lablist.y <- c("2010", "2011", "2012")
				text(seq(min(tab$tm), max(tab$tm), by=3),  par("usr")[3] - 0.8, labels = lablist.m, srt = 0, pos = 1, , xpd = NA )
				text(seq(min(tab$tm)+3, max(tab$tm), by=12),  par("usr")[3] - 2500, labels = lablist.y, srt = 0, pos = 1, , xpd = NA )
				mtext("month-year", side=1, col="black", line=3, cex=1.5)	

				# add monthly ablines and legend
				abline(v=seq(min(tab$tm), max(tab$tm), by=1),  lty=3, col="grey")
				abline(v=seq(min(tab$tm)+9, max(tab$tm), by=12), lty=3, col="black")
				legend(x="topleft", legend=c("baseline 1", "baseline 2", "baseline 3"), col=c("darkred", "cadetblue4", "mediumpurple3"),
					   pch=c(1, 4, 2), pt.cex=c(1, 1, 1), bty="n" )
				abline(h=seq(-5000, 30000, 5000), lty=3, col="grey")

				# save plot
				savePlot("graph_monthly_toll_somalia.pop3.wmf",type="wmf") 	

				
		# graph of monthly death rate and baseline (baseline method 3 only)
			
			crude.cdr <- replicate(runs, {apply(tst.analysis.som, 1, f.crude, "cdr", dat, lambda, f.bctback) } ) * tst.analysis.som[, "pop3"]  * 30.42 / 10000
			base.cdr  <- replicate(runs, {apply(tst.analysis.som, 1, f.base3, "cdr", dat, lambda, f.bctback) } ) * tst.analysis.som[, "pop3"]  * 30.42 / 10000
	
			crude.cdr <- cbind(tst.analysis.som[, c("stratum", "region", "livelihood", "tm", "y", "m", "pop3")] , crude.cdr )	
			base.cdr  <- cbind(tst.analysis.som[, c("stratum", "region", "livelihood", "tm", "y", "m", "pop3")] , base.cdr )	

			crude.u5dr <- replicate(runs, {apply(tst.analysis.som, 1, f.crude, "u5dr", dat, lambda, f.bctback) } ) * tst.analysis.som[, "pop3.u5"]  * 30.42 / 10000
			crude.u5dr <- cbind(tst.analysis.som[, c("stratum", "region", "livelihood", "tm", "y", "m", "pop3.u5")] , crude.u5dr )	
			
			write.csv(crude.cdr, "Somalia.crude.cdr.csv", row.names=FALSE)
			write.csv(base.cdr, "Somalia.baseline3.cdr.csv", row.names=FALSE)
			write.csv(crude.cdr, "Somalia.crude.u5dr.csv", row.names=FALSE)
			
			tab <- data.frame(unique(na.omit(crude.cdr)[, c("y", "m")]))
			tab <- tab[order(tab[, "y"], tab[, "m"]), ]
			tab[, "tm"] <- sort(unique(na.omit(crude.cdr)[, "tm"]))

			out <-aggregate(na.omit(crude.cdr)[, "pop3"], list(na.omit(crude.cdr)$tm), FUN=sum, na.rm=TRUE)
			tab[, "pop3"] <- out[, 2]
			
			out <-aggregate(na.omit(crude.cdr)[, 8:(runs+7)], list(na.omit(crude.cdr)$tm), FUN=sum, na.rm=TRUE)
			out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50, 0.025, 0.975)) ) } ) )			
			tab[, c("crude.est", "crude.lci", "crude.uci")] <- out

			out <-aggregate(na.omit(base.cdr)[, 8:(runs+7)], list(na.omit(base.cdr)$tm), FUN=sum, na.rm=TRUE)
			out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50, 0.025, 0.975)) ) } ) )			
			tab[, c("base.est", "base.lci", "base.uci")] <- out
			
			tab[, c("crude.est", "crude.lci", "crude.uci", "base.est", "base.lci", "base.uci")] <-
			    tab[, c("crude.est", "crude.lci", "crude.uci", "base.est", "base.lci", "base.uci")] *10000 / (tab[, "pop3"] * 30.42)
			
					
				# set general plot parameters
				par(mar=c(4, 3, 1, 2) + 0.1, cex=1.2)
				windowsFonts(Calibri=windowsFont("Calibri"))
				par(family="Calibri")
				
				# plot baseline death rate
				plot(tab[, "tm"], tab[, "base.est"], xaxt="n", ylim= c(0, max(tab[, "crude.uci"]) ),
					 xlab="", ylab="", type="l", col="darkred", lty=2, lwd=1, las=2, pch=1, yaxp=c(0, 3, 6) )

				# plot shaded confidence interval for baseline death rate
				polygon(c(tab[, "tm"], rev(tab[, "tm"])), c(tab[, "base.uci"], rev(tab[, "base.lci"]) ), col="grey", border=NA)
				# plot baseline death rate
				lines(tab[, "tm"], tab[, "base.est"], type="l", col="grey7", lty=2, lwd=1.5, pch=4 )
									
				# plot shaded confidence interval for crude death rate
					polygon(c(tab[, "tm"], rev(tab[, "tm"])), c(tab[, "crude.uci"], rev(tab[, "crude.lci"]) ), col="rosybrown2", border=NA)					
				# replot crude death rate
				lines(tab[, "tm"], tab[, "crude.est"], type="l", col="darkred", lty=1, lwd=1.5, pch=4 )				
					
				# plot average crude death rate for SS Africa (2010)
				abline(h=0.37, col="cadetblue4", lty=4, lwd=1.5, pch=2 )
				
				# add y axis label
				mtext("deaths per 10,000 person-days", side=2, col="black", line=2.5, cex=1.2)

				# add x axis labels
				axis(1, at=seq(min(tab$tm), max(tab$tm), by=3), col="black", labels=FALSE )

				lablist.m <- c("Apr", "Jul", "Oct",  "Jan", "Apr", "Jul", "Oct", "Jan", "Apr", "Jul")
				lablist.y <- c("2010", "2011", "2012")
				text(seq(min(tab$tm), max(tab$tm), by=3),  par("usr")[3] - 0.05, labels = lablist.m, srt = 0, pos = 1, , xpd = NA )
				text(seq(min(tab$tm)+3, max(tab$tm), by=12),  par("usr")[3] - 0.25, labels = lablist.y, srt = 0, pos = 1, , xpd = NA )
					#mtext("month-year", side=1, col="black", line=2.6, cex=1.2)	

				# add monthly ablines and legend
				abline(v=seq(min(tab$tm), max(tab$tm), by=1),  lty=3, col="grey")
				abline(v=seq(min(tab$tm)+9, max(tab$tm), by=12), lty=3, col="black")
				legend(x="topleft", legend=c("estimated total death rate", "estimated baseline (method 3)", "Sub-Saharan Africa average (2010)"), 
				       col=c("darkred", "grey7", "cadetblue4"), lty=c(1, 2, 4), lwd=c(1.5, 1.5, 1.5), bty="n" )
				abline(h=seq(0, 2.5, 0.5), lty=3, col="grey")

				# save plot
				savePlot("graph_monthly_cdr_somalia.pop3.wmf",type="wmf") 	

				
				
		# graph of monthly crude death rate vs. under 5 death rate
			
			tab <- data.frame(unique(na.omit(crude.cdr)[, c("y", "m")]))
			tab <- tab[order(tab[, "y"], tab[, "m"]), ]
			tab[, "tm"] <- sort(unique(na.omit(crude.cdr)[, "tm"]))

			out <-aggregate(na.omit(crude.cdr)[, "pop3"], list(na.omit(crude.cdr)$tm), FUN=sum, na.rm=TRUE)
			tab[, "pop3"] <- out[, 2]

			out <-aggregate(na.omit(crude.u5dr)[, "pop3.u5"], list(na.omit(crude.u5dr)$tm), FUN=sum, na.rm=TRUE)
			tab[, "pop3.u5"] <- out[, 2]
			
			out <-aggregate(na.omit(crude.cdr)[, 8:(runs+7)], list(na.omit(crude.cdr)$tm), FUN=sum, na.rm=TRUE)
			out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50, 0.025, 0.975)) ) } ) )			
			tab[, c("crude.est", "crude.lci", "crude.uci")] <- out

			out <-aggregate(na.omit(crude.u5dr)[, 8:(runs+7)], list(na.omit(crude.u5dr)$tm), FUN=sum, na.rm=TRUE)
			out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50, 0.025, 0.975)) ) } ) )			
			tab[, c("u5dr.est", "u5dr.lci", "u5dr.uci")] <- out
			
			tab[, c("crude.est", "crude.lci", "crude.uci")] <- tab[, c("crude.est", "crude.lci", "crude.uci")] *10000 / (tab[, "pop3"] * 30.42)
			tab[, c("u5dr.est", "u5dr.lci", "u5dr.uci")] <- tab[, c("u5dr.est", "u5dr.lci", "u5dr.uci")] *10000 / (tab[, "pop3.u5"] * 30.42)
					
					
				# set general plot parameters
				par(mar=c(4, 3, 1, 2) + 0.1, cex=1.2)
				windowsFonts(Calibri=windowsFont("Calibri"))
				par(family="Calibri")
				
				# plot crude death rate
				plot(tab[, "tm"], tab[, "crude.est"], xaxt="n", ylim= c(0, max(tab[, "u5dr.est"]) ),
					 xlab="", ylab="", type="l", col="darkred", lty=2, lwd=1, las=2, pch=1, yaxp=c(0, 8, 16) )

				# plot baseline death rate
				lines(tab[, "tm"], tab[, "u5dr.est"], type="l", col="darkblue", lty=2, lwd=1.5, pch=4 )
									
				# replot crude death rate
				lines(tab[, "tm"], tab[, "crude.est"], type="l", col="darkred", lty=1, lwd=1.5, pch=4 )				
								
				# add y axis label
				mtext("deaths per 10,000 person-days", side=2, col="black", line=2.5, cex=1.2)

				# add x axis labels
				axis(1, at=seq(min(tab$tm), max(tab$tm), by=3), col="black", labels=FALSE )

				lablist.m <- c("Apr", "Jul", "Oct",  "Jan", "Apr", "Jul", "Oct", "Jan", "Apr", "Jul")
				lablist.y <- c("2010", "2011", "2012")
				text(seq(min(tab$tm), max(tab$tm), by=3),  par("usr")[3] - 0.05, labels = lablist.m, srt = 0, pos = 1, , xpd = NA )
				text(seq(min(tab$tm)+3, max(tab$tm), by=12),  par("usr")[3] - 0.25, labels = lablist.y, srt = 0, pos = 1, , xpd = NA )
					#mtext("month-year", side=1, col="black", line=2.6, cex=1.2)	

				# add monthly ablines and legend
				abline(v=seq(min(tab$tm), max(tab$tm), by=1),  lty=3, col="grey")
				abline(v=seq(min(tab$tm)+9, max(tab$tm), by=12), lty=3, col="black")
				legend(x="topleft", legend=c("estimated crude death rate", "estimated under 5y death rate"), 
				       col=c("darkred", "darkblue"), lty=c(1, 2), lwd=c(1.5, 1.5), bty="n" )
				abline(h=seq(0, 6, 0.5), lty=3, col="grey")

				# save plot
				savePlot("graph_cdr_vs_u5dr_somalia.pop3.wmf",type="wmf") 	
				
				
				
				
				
		# raw number of crude deaths		
		
		out <-colSums(na.omit(crude.cdr)[, 8:(runs+7)], na.rm=TRUE)
		print( quantile(out, c(0.50, 0.025, 0.975)) )					
				
		# graph of monthly death toll (crude and baseline 3) - for summary
		
			tab <- data.frame(unique(na.omit(crude.cdr)[, c("y", "m")]))
			tab <- tab[order(tab[, "y"], tab[, "m"]), ]
			tab[, "tm"] <- sort(unique(na.omit(crude.cdr)[, "tm"]))

			out <-aggregate(na.omit(crude.cdr)[, "pop3"], list(na.omit(crude.cdr)$tm), FUN=sum, na.rm=TRUE)
			tab[, "pop3"] <- out[, 2]
			
			out <-aggregate(na.omit(crude.cdr)[, 8:(runs+7)], list(na.omit(crude.cdr)$tm), FUN=sum, na.rm=TRUE)
			out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50, 0.025, 0.975)) ) } ) )			
			tab[, c("crude.est", "crude.lci", "crude.uci")] <- out

			out <-aggregate(na.omit(base.cdr)[, 8:(runs+7)], list(na.omit(base.cdr)$tm), FUN=sum, na.rm=TRUE)
			out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50, 0.025, 0.975)) ) } ) )			
			tab[, c("base.est", "base.lci", "base.uci")] <- out
			
			tab <- subset(tab, tm>57 & tm<77)
			
				# set general plot parameters
				par(mar=c(4, 4.5, 1, 2) + 0.1, cex=1.2)
				windowsFonts(Calibri=windowsFont("Calibri"))
				par(family="Calibri")
				
				# plot baseline death toll
				plot(tab[, "tm"], tab[, "base.est"], xaxt="n", ylim= c(0, max(tab[, "crude.uci"]) ),
					 xlab="", ylab="", type="l", col="darkred", lty=2, lwd=1, las=2, pch=1, yaxp=c(0, 55000, 11) )

				# plot shaded confidence interval for baseline death toll
				polygon(c(tab[, "tm"], rev(tab[, "tm"])), c(tab[, "base.uci"], rev(tab[, "base.lci"]) ), col="grey", border=NA)
				# plot baseline death toll
				lines(tab[, "tm"], tab[, "base.est"], type="l", col="grey7", lty=2, lwd=1.5, pch=4 )
									
				# plot shaded confidence interval for crude death toll
					polygon(c(tab[, "tm"], rev(tab[, "tm"])), c(tab[, "crude.uci"], rev(tab[, "crude.lci"]) ), col="rosybrown2", border=NA)					
				# replot crude death toll
				lines(tab[, "tm"], tab[, "crude.est"], type="l", col="darkred", lty=1, lwd=1.5, pch=4 )				
					
				# plot death toll assuming average crude rate for SS Africa (2010)
				out <- subset(tst.analysis.som, tm>57 & tm<77)
				lines(tab[, "tm"], 0.37 * (aggregate(out[, "pop3"], list(out$tm), FUN=sum, na.rm=TRUE))[, "x"]  * 30.42 / 10000, type="l", col="cadetblue4",  lty=4, lwd=1.5, pch=2 )
				
				# add y axis label
				mtext("estimated deaths per month", side=2, col="black", line=3.75, cex=1.2)

				# add x axis labels
				axis(1, at=seq(min(tab$tm), max(tab$tm), by=3), col="black", labels=FALSE )

				lablist.m <- c("Oct",  "Jan", "Apr", "Jul", "Oct", "Jan", "Apr")
				lablist.y <- c("2010", "2011", "2012")
				text(seq(min(tab$tm), max(tab$tm), by=3),  par("usr")[3] - 500, labels = lablist.m, srt = 0, pos = 1, , xpd = NA )
				text(seq(min(tab$tm), max(tab$tm), by=9),  par("usr")[3] - 5000, labels = lablist.y, srt = 0, pos = 1, , xpd = NA )
					#mtext("month-year", side=1, col="black", line=2.6, cex=1.2)	

				# add monthly ablines and legend
				abline(v=seq(min(tab$tm), max(tab$tm), by=1),  lty=3, col="grey")
				abline(v=seq(min(tab$tm)+3, max(tab$tm), by=12), lty=3, col="black")
				legend(x="topright", legend=c("estimated total deaths", "estimated baseline deaths (method 3)", "assuming Sub-Saharan Africa average (2010)"), 
				       col=c("darkred", "grey7", "cadetblue4"), lty=c(1, 2, 4), lwd=c(1.5, 1.5, 1.5), bty="n", cex=0.9 )
				abline(h=seq(0, 55000, 5000), lty=3, col="grey")

				# save plot
				savePlot("graph_monthly_crude_vs_base3_somalia.pop3.wmf",type="wmf") 	

			
		# graph excess deaths in Afgoye and Banadir

				# create table
				tab <- data.frame(unique(na.omit(sim.cdr.base3.pop3)[, c("y", "m")]))
				tab <- tab[order(tab[, "y"], tab[, "m"]), ]
				tab[, "tm"] <- sort(unique(na.omit(sim.cdr.base3.pop3)[, "tm"]))

				out <-aggregate(na.omit(subset(sim.cdr.base3.pop3, stratum=="lsh_idp"))[, 8:(runs+7)], list(na.omit(subset(sim.cdr.base3.pop3, stratum=="lsh_idp"))$tm), FUN=sum, na.rm=TRUE)
				out <- apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } )			
				out <- cbind(sort(unique(na.omit(subset(sim.cdr.base3.pop3, stratum=="lsh_idp"))[, "tm"])) , out)
				colnames(out) <- c("tm", "lsh_idp")
				tab <- merge(tab, out, by="tm", all.x=TRUE)

				out <-aggregate(na.omit(subset(sim.cdr.base3.pop3, stratum=="ban_idp"))[, 8:(runs+7)], list(na.omit(subset(sim.cdr.base3.pop3, stratum=="ban_idp"))$tm), FUN=sum, na.rm=TRUE)
				out <- apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } )			
				out <- cbind(sort(unique(na.omit(subset(sim.cdr.base3.pop3, stratum=="ban_idp"))[, "tm"])) , out)
				colnames(out) <- c("tm", "ban_idp")
				tab <- merge(tab, out, by="tm", all.x=TRUE)

				out <-aggregate(na.omit(subset(sim.cdr.base3.pop3, stratum=="ban_urb"))[, 8:(runs+7)], list(na.omit(subset(sim.cdr.base3.pop3, stratum=="ban_urb"))$tm), FUN=sum, na.rm=TRUE)
				out <- apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } )			
				out <- cbind(sort(unique(na.omit(subset(sim.cdr.base3.pop3, stratum=="ban_urb"))[, "tm"])) , out)
				colnames(out) <- c("tm", "ban_urb")
				tab <- merge(tab, out, by="tm", all.x=TRUE)

				
				# set general plot parameters
				par(mar=c(5, 5, 2, 2) + 0.1, cex=1.5)
				windowsFonts(Calibri=windowsFont("Calibri"))
				par(family="Calibri")
				
				# plot Lower Shabelle IDPs
				plot(tab[, "tm"], tab[, "lsh_idp"], xaxt="n", ylim=c(min(tab[, c("lsh_idp", "ban_idp", "ban_urb")], na.rm=TRUE), max(tab[, c("lsh_idp", "ban_idp", "ban_urb")], na.rm=TRUE)),
					 xlab="", ylab="", type="o", col="darkred", lty=1, lwd=1, las=2, pch=1, yaxp=c(-1000, 5000, 6) )
				mtext("monthly estimated excess deaths (all ages)", side=2, col="black", line=4, cex=1.5)
				
				# plot Banadir IDPs
				lines(tab[, "tm"], tab[, "ban_idp"], type="o", col="cadetblue4", lty=1, lwd=1, pch=4 )
				
				# plot Banadir urban
				lines(tab[, "tm"], tab[, "ban_urb"], type="o", col="mediumpurple3", lty=1, lwd=1, pch=2 )
		
				# add x axis labels
				axis(1, at=seq(min(tab$tm), max(tab$tm), by=3), col="black", labels=FALSE )

				lablist.m <- c("Apr", "Jul", "Oct",  "Jan", "Apr", "Jul", "Oct", "Jan", "Apr", "Jul")
				lablist.y <- c("2010", "2011", "2012")
				text(seq(min(tab$tm), max(tab$tm), by=3),  par("usr")[3] - 0.8, labels = lablist.m, srt = 0, pos = 1, , xpd = NA )
				text(seq(min(tab$tm)+3, max(tab$tm), by=12),  par("usr")[3] - 500, labels = lablist.y, srt = 0, pos = 1, , xpd = NA )
				mtext("month-year", side=1, col="black", line=3, cex=1.5)	

				# add monthly ablines and legend
				abline(v=seq(min(tab$tm), max(tab$tm), by=1),  lty=3, col="grey")
				abline(v=seq(min(tab$tm)+9, max(tab$tm), by=12), lty=3, col="black")
				legend(x="topleft", legend=c("Lower Shabelle IDPs (Afgoye corridor)", "Mogadishu IDPs", "Mogadishu urban residents"),
				       col=c("darkred", "cadetblue4", "mediumpurple3"), pch=c(1, 4, 2), pt.cex=c(1, 1, 1), bty="n" )
				abline(h=seq(-1000, 5000, 1000), lty=3, col="grey")

				# save plot
				savePlot("graph_monthly_toll_afgoye_banadir.pop3.wmf",type="wmf") 	


	# percent dead by stratum
	tab <- data.frame(unique(na.omit(sim.cdr.base1.pop3)[, c("region", "livelihood")]))
	
	out <- na.omit(subset(sim.cdr.base1.pop3, tm>57 & tm<77) )
	out[, 8:(runs+7)] <- apply(out[, 8:(runs+7)], 2, function(f.out, f.pop) {return(100 * f.out / f.pop)} , out[, "pop3"] )
	out <- aggregate(out[, 8:(runs+7)], list(na.omit(out)$stratum), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } ) )
	out <- round(out, 1)
	tab[, "base1"] <- sapply(out, function(f.out) {return(max(0, f.out)) } )

	out <- na.omit(subset(sim.u5dr.base1.pop3, tm>57 & tm<77) )
	out[, 8:(runs+7)] <- apply(out[, 8:(runs+7)], 2, function(f.out, f.pop) {return(100 * f.out / f.pop)} , out[, "pop3.u5"] )
	out <- aggregate(out[, 8:(runs+7)], list(na.omit(out)$stratum), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } ) )
	out <- round(out, 1)
	tab[, "base1.u5"] <- sapply(out, function(f.out) {return(max(0, f.out)) } )

	out <- na.omit(subset(sim.cdr.base2.pop3, tm>57 & tm<77) )
	out[, 8:(runs+7)] <- apply(out[, 8:(runs+7)], 2, function(f.out, f.pop) {return(100 * f.out / f.pop)} , out[, "pop3"] )
	out <- aggregate(out[, 8:(runs+7)], list(na.omit(out)$stratum), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } ) )
	out <- round(out, 1)
	tab[, "base2"] <- sapply(out, function(f.out) {return(max(0, f.out)) } )

	out <- na.omit(subset(sim.u5dr.base2.pop3, tm>57 & tm<77) )
	out[, 8:(runs+7)] <- apply(out[, 8:(runs+7)], 2, function(f.out, f.pop) {return(100 * f.out / f.pop)} , out[, "pop3.u5"] )
	out <- aggregate(out[, 8:(runs+7)], list(na.omit(out)$stratum), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } ) )
	out <- round(out, 1)
	tab[, "base2.u5"] <- sapply(out, function(f.out) {return(max(0, f.out)) } )

	out <- na.omit(subset(sim.cdr.base3.pop3, tm>57 & tm<77) )
	out[, 8:(runs+7)] <- apply(out[, 8:(runs+7)], 2, function(f.out, f.pop) {return(100 * f.out / f.pop)} , out[, "pop3"] )
	out <- aggregate(out[, 8:(runs+7)], list(na.omit(out)$stratum), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } ) )
	out <- round(out, 1)
	tab[, "base3"] <- sapply(out, function(f.out) {return(max(0, f.out)) } )

	out <- na.omit(subset(sim.u5dr.base3.pop3, tm>57 & tm<77) )
	out[, 8:(runs+7)] <- apply(out[, 8:(runs+7)], 2, function(f.out, f.pop) {return(100 * f.out / f.pop)} , out[, "pop3.u5"] )
	out <- aggregate(out[, 8:(runs+7)], list(na.omit(out)$stratum), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } ) )
	out <- round(out, 1)
	tab[, "base3.u5"] <- sapply(out, function(f.out) {return(max(0, f.out)) } )
	
	tab[nrow(tab)+1, 1] <- NA

	out <- na.omit(subset(sim.cdr.base1.pop3, tm>57 & tm<77) )
	out <- aggregate(out[, 7:(runs+7)], list(na.omit(out)$tm), FUN=sum, na.rm=TRUE)
	out <- apply(out[, 3:(runs+2)], 2, function(f.out, f.pop) {return(100 * f.out / f.pop)} , out[, "pop3"] )
	out <- round(quantile(colSums(out), c(0.50) ), 1)
	tab[nrow(tab), "base1"] <- out
	
	out <- na.omit(subset(sim.u5dr.base1.pop3, tm>57 & tm<77) )
	out <- aggregate(out[, 7:(runs+7)], list(na.omit(out)$tm), FUN=sum, na.rm=TRUE)
	out <- apply(out[, 3:(runs+2)], 2, function(f.out, f.pop) {return(100 * f.out / f.pop)} , out[, "pop3.u5"] )
	out <- round(quantile(colSums(out), c(0.50) ), 1)
	tab[nrow(tab), "base1.u5"] <- out
	
	out <- na.omit(subset(sim.cdr.base2.pop3, tm>57 & tm<77) )
	out <- aggregate(out[, 7:(runs+7)], list(na.omit(out)$tm), FUN=sum, na.rm=TRUE)
	out <- apply(out[, 3:(runs+2)], 2, function(f.out, f.pop) {return(100 * f.out / f.pop)} , out[, "pop3"] )
	out <- round(quantile(colSums(out), c(0.50) ), 1)
	tab[nrow(tab), "base2"] <- out
	
	out <- na.omit(subset(sim.u5dr.base2.pop3, tm>57 & tm<77) )
	out <- aggregate(out[, 7:(runs+7)], list(na.omit(out)$tm), FUN=sum, na.rm=TRUE)
	out <- apply(out[, 3:(runs+2)], 2, function(f.out, f.pop) {return(100 * f.out / f.pop)} , out[, "pop3.u5"] )
	out <- round(quantile(colSums(out), c(0.50) ), 1)
	tab[nrow(tab), "base2.u5"] <- out

	out <- na.omit(subset(sim.cdr.base3.pop3, tm>57 & tm<77) )
	out <- aggregate(out[, 7:(runs+7)], list(na.omit(out)$tm), FUN=sum, na.rm=TRUE)
	out <- apply(out[, 3:(runs+2)], 2, function(f.out, f.pop) {return(100 * f.out / f.pop)} , out[, "pop3"] )
	out <- round(quantile(colSums(out), c(0.50) ), 1)
	tab[nrow(tab), "base3"] <- out
	
	out <- na.omit(subset(sim.u5dr.base3.pop3, tm>57 & tm<77) )
	out <- aggregate(out[, 7:(runs+7)], list(na.omit(out)$tm), FUN=sum, na.rm=TRUE)
	out <- apply(out[, 3:(runs+2)], 2, function(f.out, f.pop) {return(100 * f.out / f.pop)} , out[, "pop3.u5"] )
	out <- round(quantile(colSums(out), c(0.50) ), 1)
	tab[nrow(tab), "base3.u5"] <- out

	write.csv(tab, "Somalia_percent_dead_stratum.pop3.csv", row.names=FALSE)
	

	# percent dead by region
	tab <- data.frame(unique(na.omit(sim.cdr.base1.pop3)[, "region"]))
	
	out <- na.omit(subset(sim.cdr.base1.pop3, tm>57 & tm<77) )
	pop <- aggregate(out[, "pop3"], list(out$region, out$tm), FUN=sum, na.rm=TRUE)
	pop <- aggregate(pop[, "x"], list(pop$Group.1), FUN=mean, na.rm=TRUE)
	out <- aggregate(out[, 8:(runs+7)], list(na.omit(out)$region), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } ) )
	tab[, "base1"] <- sapply(round(out*100/pop[, "x"], 1), function(f.out) {return(max(0, f.out)) }  )

	out <- na.omit(subset(sim.u5dr.base1.pop3, tm>57 & tm<77) )
	pop <- aggregate(out[, "pop3.u5"], list(out$region, out$tm), FUN=sum, na.rm=TRUE)
	pop <- aggregate(pop[, "x"], list(pop$Group.1), FUN=mean, na.rm=TRUE)
	out <- aggregate(out[, 8:(runs+7)], list(na.omit(out)$region), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } ) )
	tab[, "base1.u5"] <- sapply(round(out*100/pop[, "x"], 1), function(f.out) {return(max(0, f.out)) }  )

	out <- na.omit(subset(sim.cdr.base2.pop3, tm>57 & tm<77) )
	pop <- aggregate(out[, "pop3"], list(out$region, out$tm), FUN=sum, na.rm=TRUE)
	pop <- aggregate(pop[, "x"], list(pop$Group.1), FUN=mean, na.rm=TRUE)
	out <- aggregate(out[, 8:(runs+7)], list(na.omit(out)$region), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } ) )
	tab[, "base2"] <- sapply(round(out*100/pop[, "x"], 1), function(f.out) {return(max(0, f.out)) }  )

	out <- na.omit(subset(sim.u5dr.base2.pop3, tm>57 & tm<77) )
	pop <- aggregate(out[, "pop3.u5"], list(out$region, out$tm), FUN=sum, na.rm=TRUE)
	pop <- aggregate(pop[, "x"], list(pop$Group.1), FUN=mean, na.rm=TRUE)
	out <- aggregate(out[, 8:(runs+7)], list(na.omit(out)$region), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } ) )
	tab[, "base2.u5"] <- sapply(round(out*100/pop[, "x"], 1), function(f.out) {return(max(0, f.out)) }  )

	out <- na.omit(subset(sim.cdr.base3.pop3, tm>57 & tm<77) )
	pop <- aggregate(out[, "pop3"], list(out$region, out$tm), FUN=sum, na.rm=TRUE)
	pop <- aggregate(pop[, "x"], list(pop$Group.1), FUN=mean, na.rm=TRUE)
	out <- aggregate(out[, 8:(runs+7)], list(na.omit(out)$region), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } ) )
	tab[, "base3"] <- sapply(round(out*100/pop[, "x"], 1), function(f.out) {return(max(0, f.out)) }  )

	out <- na.omit(subset(sim.u5dr.base3.pop3, tm>57 & tm<77) )
	pop <- aggregate(out[, "pop3.u5"], list(out$region, out$tm), FUN=sum, na.rm=TRUE)
	pop <- aggregate(pop[, "x"], list(pop$Group.1), FUN=mean, na.rm=TRUE)
	out <- aggregate(out[, 8:(runs+7)], list(na.omit(out)$region), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } ) )
	tab[, "base3.u5"] <- sapply(round(out*100/pop[, "x"], 1), function(f.out) {return(max(0, f.out)) }  )

	tab[nrow(tab)+1, 1] <- NA

	out <- na.omit(subset(sim.cdr.base1.pop3, tm>57 & tm<77) )
	pop <- aggregate(out[, "pop3"], list(out$tm), FUN=sum, na.rm=TRUE)
	pop <- mean(pop)
	tab[nrow(tab), "base1"] <- max(0, round(median(colSums(out[, 8:(runs+7)], na.rm=TRUE) ) * 100 / pop["x"], 1) )

	out <- na.omit(subset(sim.u5dr.base1.pop3, tm>57 & tm<77) )
	pop <- aggregate(out[, "pop3.u5"], list(out$tm), FUN=sum, na.rm=TRUE)
	pop <- mean(pop)
	tab[nrow(tab), "base1.u5"] <- max(0, round(median(colSums(out[, 8:(runs+7)], na.rm=TRUE) ) * 100 / pop["x"], 1) )

	out <- na.omit(subset(sim.cdr.base2.pop3, tm>57 & tm<77) )
	pop <- aggregate(out[, "pop3"], list(out$tm), FUN=sum, na.rm=TRUE)
	pop <- mean(pop)
	tab[nrow(tab), "base2"] <- max(0, round(median(colSums(out[, 8:(runs+7)], na.rm=TRUE) ) * 100 / pop["x"], 1) )

	out <- na.omit(subset(sim.u5dr.base2.pop3, tm>57 & tm<77) )
	pop <- aggregate(out[, "pop3.u5"], list(out$tm), FUN=sum, na.rm=TRUE)
	pop <- mean(pop)
	tab[nrow(tab), "base2.u5"] <- max(0, round(median(colSums(out[, 8:(runs+7)], na.rm=TRUE) ) * 100 / pop["x"], 1) )

	out <- na.omit(subset(sim.cdr.base3.pop3, tm>57 & tm<77) )
	pop <- aggregate(out[, "pop3"], list(out$tm), FUN=sum, na.rm=TRUE)
	pop <- mean(pop)
	tab[nrow(tab), "base3"] <- max(0, round(median(colSums(out[, 8:(runs+7)], na.rm=TRUE) ) * 100 / pop["x"], 1) )

	out <- na.omit(subset(sim.u5dr.base3.pop3, tm>57 & tm<77) )
	pop <- aggregate(out[, "pop3.u5"], list(out$tm), FUN=sum, na.rm=TRUE)
	pop <- mean(pop)
	tab[nrow(tab), "base3.u5"] <- max(0, round(median(colSums(out[, 8:(runs+7)], na.rm=TRUE) ) * 100 / pop["x"], 1) )
	
	write.csv(tab, "Somalia_percent_dead_region.pop3.csv", row.names=FALSE)
	
	

	# percent dead by livelihood
	tab <- data.frame(unique(na.omit(sim.cdr.base1.pop3)[, "livelihood"]))
	
	out <- na.omit(subset(sim.cdr.base1.pop3, tm>57 & tm<77) )
	pop <- aggregate(out[, "pop3"], list(out$livelihood, out$tm), FUN=sum, na.rm=TRUE)
	pop <- aggregate(pop[, "x"], list(pop$Group.1), FUN=mean, na.rm=TRUE)
	out <- aggregate(out[, 8:(runs+7)], list(na.omit(out)$livelihood), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } ) )
	tab[, "base1"] <- sapply(round(out*100/pop[, "x"], 1), function(f.out) {return(max(0, f.out)) }  )

	out <- na.omit(subset(sim.u5dr.base1.pop3, tm>57 & tm<77) )
	pop <- aggregate(out[, "pop3.u5"], list(out$livelihood, out$tm), FUN=sum, na.rm=TRUE)
	pop <- aggregate(pop[, "x"], list(pop$Group.1), FUN=mean, na.rm=TRUE)
	out <- aggregate(out[, 8:(runs+7)], list(na.omit(out)$livelihood), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } ) )
	tab[, "base1.u5"] <- sapply(round(out*100/pop[, "x"], 1), function(f.out) {return(max(0, f.out)) }  )

	out <- na.omit(subset(sim.cdr.base2.pop3, tm>57 & tm<77) )
	pop <- aggregate(out[, "pop3"], list(out$livelihood, out$tm), FUN=sum, na.rm=TRUE)
	pop <- aggregate(pop[, "x"], list(pop$Group.1), FUN=mean, na.rm=TRUE)
	out <- aggregate(out[, 8:(runs+7)], list(na.omit(out)$livelihood), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } ) )
	tab[, "base2"] <- sapply(round(out*100/pop[, "x"], 1), function(f.out) {return(max(0, f.out)) }  )

	out <- na.omit(subset(sim.u5dr.base2.pop3, tm>57 & tm<77) )
	pop <- aggregate(out[, "pop3.u5"], list(out$livelihood, out$tm), FUN=sum, na.rm=TRUE)
	pop <- aggregate(pop[, "x"], list(pop$Group.1), FUN=mean, na.rm=TRUE)
	out <- aggregate(out[, 8:(runs+7)], list(na.omit(out)$livelihood), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } ) )
	tab[, "base2.u5"] <- sapply(round(out*100/pop[, "x"], 1), function(f.out) {return(max(0, f.out)) }  )

	out <- na.omit(subset(sim.cdr.base3.pop3, tm>57 & tm<77) )
	pop <- aggregate(out[, "pop3"], list(out$livelihood, out$tm), FUN=sum, na.rm=TRUE)
	pop <- aggregate(pop[, "x"], list(pop$Group.1), FUN=mean, na.rm=TRUE)
	out <- aggregate(out[, 8:(runs+7)], list(na.omit(out)$livelihood), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } ) )
	tab[, "base3"] <- sapply(round(out*100/pop[, "x"], 1), function(f.out) {return(max(0, f.out)) }  )

	out <- na.omit(subset(sim.u5dr.base3.pop3, tm>57 & tm<77) )
	pop <- aggregate(out[, "pop3.u5"], list(out$livelihood, out$tm), FUN=sum, na.rm=TRUE)
	pop <- aggregate(pop[, "x"], list(pop$Group.1), FUN=mean, na.rm=TRUE)
	out <- aggregate(out[, 8:(runs+7)], list(na.omit(out)$livelihood), FUN=sum, na.rm=TRUE)
	out <- t(apply(out[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } ) )
	tab[, "base3.u5"] <- sapply(round(out*100/pop[, "x"], 1), function(f.out) {return(max(0, f.out)) }  )

	tab[nrow(tab)+1, 1] <- NA

	out <- na.omit(subset(sim.cdr.base1.pop3, tm>57 & tm<77) )
	pop <- aggregate(out[, "pop3"], list(out$tm), FUN=sum, na.rm=TRUE)
	pop <- mean(pop)
	tab[nrow(tab), "base1"] <- max(0, round(median(colSums(out[, 8:(runs+7)], na.rm=TRUE) ) * 100 / pop["x"], 1) )

	out <- na.omit(subset(sim.u5dr.base1.pop3, tm>57 & tm<77) )
	pop <- aggregate(out[, "pop3.u5"], list(out$tm), FUN=sum, na.rm=TRUE)
	pop <- mean(pop)
	tab[nrow(tab), "base1.u5"] <- max(0, round(median(colSums(out[, 8:(runs+7)], na.rm=TRUE) ) * 100 / pop["x"], 1) )

	out <- na.omit(subset(sim.cdr.base2.pop3, tm>57 & tm<77) )
	pop <- aggregate(out[, "pop3"], list(out$tm), FUN=sum, na.rm=TRUE)
	pop <- mean(pop)
	tab[nrow(tab), "base2"] <- max(0, round(median(colSums(out[, 8:(runs+7)], na.rm=TRUE) ) * 100 / pop["x"], 1) )

	out <- na.omit(subset(sim.u5dr.base2.pop3, tm>57 & tm<77) )
	pop <- aggregate(out[, "pop3.u5"], list(out$tm), FUN=sum, na.rm=TRUE)
	pop <- mean(pop)
	tab[nrow(tab), "base2.u5"] <- max(0, round(median(colSums(out[, 8:(runs+7)], na.rm=TRUE) ) * 100 / pop["x"], 1) )

	out <- na.omit(subset(sim.cdr.base3.pop3, tm>57 & tm<77) )
	pop <- aggregate(out[, "pop3"], list(out$tm), FUN=sum, na.rm=TRUE)
	pop <- mean(pop)
	tab[nrow(tab), "base3"] <- max(0, round(median(colSums(out[, 8:(runs+7)], na.rm=TRUE) ) * 100 / pop["x"], 1) )

	out <- na.omit(subset(sim.u5dr.base3.pop3, tm>57 & tm<77) )
	pop <- aggregate(out[, "pop3.u5"], list(out$tm), FUN=sum, na.rm=TRUE)
	pop <- mean(pop)
	tab[nrow(tab), "base3.u5"] <- max(0, round(median(colSums(out[, 8:(runs+7)], na.rm=TRUE) ) * 100 / pop["x"], 1) )
	
	write.csv(tab, "Somalia_percent_dead_livelihood.pop3.csv", row.names=FALSE)
	
	
	
	
#.........................................................................................
### Ethiopia camps estimation

	runs <- 10000
	# Ethiopia
	tst.analysis.eth <- subset(tst, location=="Ethiopia" & tm > 51 & tm < 80)
	
		# simulation with optimistic scenario, baseline method 1, population dataset being analysed
		sim.cdr.opt.base1.pop3.eth <- replicate(runs, {
				(tst.analysis.eth[, "cdr_opt"]  - apply(tst.analysis.eth, 1, f.base1, base_tot, 5, "cdr") ) * tst.analysis.eth[, "pop3"] * 30.42 / 10000
			} )	
		sim.cdr.opt.base1.pop3.eth <- cbind(tst.analysis.eth[, c("stratum", "region", "livelihood", "tm", "y", "m", "pop3")] , sim.cdr.opt.base1.pop3.eth )	
		write.csv(sim.cdr.opt.base1.pop3.eth, "ethiopia_sim.cdr.opt.base1.pop3.csv")

		sim.u5dr.opt.base1.pop3.eth <- replicate(runs, {
				(tst.analysis.eth[, "u5dr_opt"]  - apply(tst.analysis.eth, 1, f.base1, base_tot, 5, "u5dr") ) * tst.analysis.eth[, "pop3"] * sample(prop.u5.eth, nrow(tst.analysis.eth), replace=TRUE) * 30.42 / 10000
			} )	
		sim.u5dr.opt.base1.pop3.eth <- cbind(tst.analysis.eth[, c("stratum", "region", "livelihood", "tm", "y", "m", "pop3.u5")] , sim.u5dr.opt.base1.pop3.eth )	
		write.csv(sim.u5dr.opt.base1.pop3.eth, "ethiopia_sim.u5dr.opt.base1.pop3.csv")

			
		# simulation with pessimistic scenario, baseline method 1, population dataset being analysed			
		sim.cdr.pes.base1.pop3.eth <- replicate(runs, {
				(tst.analysis.eth[, "cdr_pes"]  - apply(tst.analysis.eth, 1, f.base1, base_tot, 5, "cdr") ) * tst.analysis.eth[, "pop3"] * 30.42 / 10000
			} )	
		sim.cdr.pes.base1.pop3.eth <- cbind(tst.analysis.eth[, c("stratum", "region", "livelihood", "tm", "y", "m", "pop3")] , sim.cdr.pes.base1.pop3.eth )	
		write.csv(sim.cdr.pes.base1.pop3.eth, "ethiopia_sim.cdr.pes.base1.pop3.csv")
			
		sim.u5dr.pes.base1.pop3.eth <- replicate(runs, {
				(tst.analysis.eth[, "u5dr_pes"]  - apply(tst.analysis.eth, 1, f.base1, base_tot, 5, "u5dr") ) * tst.analysis.eth[, "pop3"] * sample(prop.u5.eth, nrow(tst.analysis.eth), replace=TRUE) * 30.42 / 10000
			} )	
		sim.u5dr.pes.base1.pop3.eth <- cbind(tst.analysis.eth[, c("stratum", "region", "livelihood", "tm", "y", "m", "pop3.u5")] , sim.u5dr.pes.base1.pop3.eth )	
		write.csv(sim.u5dr.pes.base1.pop3.eth, "ethiopia_sim.u5dr.pes.base1.pop3.csv")
		
		# ...

		# simulation with optimistic scenario, baseline method 2, population dataset being analysed
		sim.cdr.opt.base2.pop3.eth <- replicate(runs, {
				(tst.analysis.eth[, "cdr_opt"]  - replicate(nrow(tst.analysis.eth), {f.base2(base_ipc, "cdr") } ) ) * tst.analysis.eth[, "pop3"] * 30.42 / 10000
			} )	
		sim.cdr.opt.base2.pop3.eth <- cbind(tst.analysis.eth[, c("stratum", "region", "livelihood", "tm", "y", "m", "pop3")] , sim.cdr.opt.base2.pop3.eth )	
		write.csv(sim.cdr.opt.base2.pop3.eth, "ethiopia_sim.cdr.opt.base2.pop3.csv")

		sim.u5dr.opt.base2.pop3.eth <- replicate(runs, {
				(tst.analysis.eth[, "u5dr_opt"]  - replicate(nrow(tst.analysis.eth), {f.base2(base_ipc, "u5dr") } ) ) * tst.analysis.eth[, "pop3"] * sample(prop.u5.eth, nrow(tst.analysis.eth), replace=TRUE) * 30.42 / 10000
			} )	
		sim.u5dr.opt.base2.pop3.eth <- cbind(tst.analysis.eth[, c("stratum", "region", "livelihood", "tm", "y", "m", "pop3.u5")] , sim.u5dr.opt.base2.pop3.eth )	
		write.csv(sim.u5dr.opt.base2.pop3.eth, "ethiopia_sim.u5dr.opt.base2.pop3.csv")

			
		# simulation with pessimistic scenario, baseline method 2, population dataset being analysed			
		sim.cdr.pes.base2.pop3.eth <- replicate(runs, {
				(tst.analysis.eth[, "cdr_pes"]  - replicate(nrow(tst.analysis.eth), {f.base2(base_ipc, "cdr") } ) ) * tst.analysis.eth[, "pop3"] * 30.42 / 10000
			} )	
		sim.cdr.pes.base2.pop3.eth <- cbind(tst.analysis.eth[, c("stratum", "region", "livelihood", "tm", "y", "m", "pop3")] , sim.cdr.pes.base2.pop3.eth )	
		write.csv(sim.cdr.pes.base2.pop3.eth, "ethiopia_sim.cdr.pes.base2.pop3.csv")
		
		sim.u5dr.pes.base2.pop3.eth <- replicate(runs, {
				(tst.analysis.eth[, "u5dr_pes"]  - replicate(nrow(tst.analysis.eth), {f.base2(base_ipc, "u5dr") } ) ) * tst.analysis.eth[, "pop3"] * sample(prop.u5.eth, nrow(tst.analysis.eth), replace=TRUE) * 30.42 / 10000
			} )	
		sim.u5dr.pes.base2.pop3.eth <- cbind(tst.analysis.eth[, c("stratum", "region", "livelihood", "tm", "y", "m", "pop3.u5")] , sim.u5dr.pes.base2.pop3.eth )	
		write.csv(sim.u5dr.pes.base2.pop3.eth, "ethiopia_sim.u5dr.pes.base2.pop3.csv")
				
		# ...

		# simulation with optimistic scenario, baseline method 3, population dataset being analysed
		sim.cdr.opt.base3.pop3.eth <- replicate(runs, {
				(tst.analysis.eth[, "cdr_opt"]  - apply(tst.analysis.eth, 1, f.base3.eth, "cdr", tst.analysis.som, dat, lambda, f.bctback) ) * tst.analysis.eth[, "pop3"] * 30.42 / 10000
			} )	
		sim.cdr.opt.base3.pop3.eth <- cbind(tst.analysis.eth[, c("stratum", "region", "livelihood", "tm", "y", "m", "pop3")] , sim.cdr.opt.base3.pop3.eth )	
		write.csv(sim.cdr.opt.base3.pop3.eth, "ethiopia_sim.cdr.opt.base3.pop3.csv")

		sim.u5dr.opt.base3.pop3.eth <- replicate(runs, {
				(tst.analysis.eth[, "u5dr_opt"]  - apply(tst.analysis.eth, 1, f.base3.eth, "u5dr", tst.analysis.som, dat, lambda, f.bctback) ) * tst.analysis.eth[, "pop3"] * sample(prop.u5.eth, nrow(tst.analysis.eth), replace=TRUE) * 30.42 / 10000
			} )	
		sim.u5dr.opt.base3.pop3.eth <- cbind(tst.analysis.eth[, c("stratum", "region", "livelihood", "tm", "y", "m", "pop3.u5")] , sim.u5dr.opt.base3.pop3.eth )	
		write.csv(sim.u5dr.opt.base3.pop3.eth, "ethiopia_sim.u5dr.opt.base3.pop3.csv")

		# simulation with pessimistic scenario, baseline method 3, population dataset being analysed			
		sim.cdr.pes.base3.pop3.eth <- replicate(runs, {
				(tst.analysis.eth[, "cdr_pes"]  - apply(tst.analysis.eth, 1, f.base3.eth, "cdr", tst.analysis.som, dat, lambda, f.bctback) ) * tst.analysis.eth[, "pop3"] * 30.42 / 10000
			} )	
		sim.cdr.pes.base3.pop3.eth <- cbind(tst.analysis.eth[, c("stratum", "region", "livelihood", "tm", "y", "m", "pop3")] , sim.cdr.pes.base3.pop3.eth )	
		write.csv(sim.cdr.pes.base3.pop3.eth, "ethiopia_sim.cdr.pes.base3.pop3.csv")

		sim.u5dr.pes.base3.pop3.eth <- replicate(runs, {
				(tst.analysis.eth[, "u5dr_pes"]  - apply(tst.analysis.eth, 1, f.base3.eth, "u5dr", tst.analysis.som, dat, lambda, f.bctback) ) * tst.analysis.eth[, "pop3"] * sample(prop.u5.eth, nrow(tst.analysis.eth), replace=TRUE) * 30.42 / 10000
			} )	
		sim.u5dr.pes.base3.pop3.eth <- cbind(tst.analysis.eth[, c("stratum", "region", "livelihood", "tm", "y", "m", "pop3.u5")] , sim.u5dr.pes.base3.pop3.eth )	
		write.csv(sim.u5dr.pes.base3.pop3.eth, "ethiopia_sim.u5dr.pes.base3.pop3.csv")

	
		# analysis
	
			# create result tables

				# by stratum
				tab <- data.frame(unique(na.omit(sim.cdr.opt.base1.pop3.eth)[, c("region", "livelihood")]))
				
				out.opt <-aggregate(na.omit(sim.cdr.opt.base1.pop3.eth)[, 8:(runs+7)], list(na.omit(sim.cdr.opt.base1.pop3.eth)$stratum), FUN=sum, na.rm=TRUE)				
				out.opt <- apply(out.opt[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } )
				out.opt <- round(out.opt/100, 0)*100
				out.pes <-aggregate(na.omit(sim.cdr.pes.base1.pop3.eth)[, 8:(runs+7)], list(na.omit(sim.cdr.pes.base1.pop3.eth)$stratum), FUN=sum, na.rm=TRUE)				
				out.pes <- apply(out.pes[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } )
				out.pes <- round(out.pes/100, 0)*100
				tab[, "base1"] <- paste(out.opt, " to ", out.pes, sep="")

				out.opt <-aggregate(na.omit(sim.u5dr.opt.base1.pop3.eth)[, 8:(runs+7)], list(na.omit(sim.u5dr.opt.base1.pop3.eth)$stratum), FUN=sum, na.rm=TRUE)				
				out.opt <- apply(out.opt[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } )
				out.opt <- round(out.opt/100, 0)*100
				out.pes <-aggregate(na.omit(sim.u5dr.pes.base1.pop3.eth)[, 8:(runs+7)], list(na.omit(sim.u5dr.pes.base1.pop3.eth)$stratum), FUN=sum, na.rm=TRUE)				
				out.pes <- apply(out.pes[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } )
				out.pes <- round(out.pes/100, 0)*100
				tab[, "base1.u5"] <- paste(out.opt, " to ", out.pes, sep="")
				
				out.opt <-aggregate(na.omit(sim.cdr.opt.base2.pop3.eth)[, 8:(runs+7)], list(na.omit(sim.cdr.opt.base2.pop3.eth)$stratum), FUN=sum, na.rm=TRUE)				
				out.opt <- apply(out.opt[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } )
				out.opt <- round(out.opt/100, 0)*100
				out.pes <-aggregate(na.omit(sim.cdr.pes.base2.pop3.eth)[, 8:(runs+7)], list(na.omit(sim.cdr.pes.base2.pop3.eth)$stratum), FUN=sum, na.rm=TRUE)				
				out.pes <- apply(out.pes[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } )
				out.pes <- round(out.pes/100, 0)*100
				tab[, "base2"] <- paste(out.opt, " to ", out.pes, sep="")

				out.opt <-aggregate(na.omit(sim.u5dr.opt.base2.pop3.eth)[, 8:(runs+7)], list(na.omit(sim.u5dr.opt.base2.pop3.eth)$stratum), FUN=sum, na.rm=TRUE)				
				out.opt <- apply(out.opt[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } )
				out.opt <- round(out.opt/100, 0)*100
				out.pes <-aggregate(na.omit(sim.u5dr.pes.base2.pop3.eth)[, 8:(runs+7)], list(na.omit(sim.u5dr.pes.base2.pop3.eth)$stratum), FUN=sum, na.rm=TRUE)				
				out.pes <- apply(out.pes[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } )
				out.pes <- round(out.pes/100, 0)*100
				tab[, "base2.u5"] <- paste(out.opt, " to ", out.pes, sep="")

				out.opt <-aggregate(na.omit(sim.cdr.opt.base3.pop3.eth)[, 8:(runs+7)], list(na.omit(sim.cdr.opt.base3.pop3.eth)$stratum), FUN=sum, na.rm=TRUE)				
				out.opt <- apply(out.opt[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } )
				out.opt <- round(out.opt/100, 0)*100
				out.pes <-aggregate(na.omit(sim.cdr.pes.base3.pop3.eth)[, 8:(runs+7)], list(na.omit(sim.cdr.pes.base3.pop3.eth)$stratum), FUN=sum, na.rm=TRUE)				
				out.pes <- apply(out.pes[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } )
				out.pes <- round(out.pes/100, 0)*100
				tab[, "base3"] <- paste(out.opt, " to ", out.pes, sep="")

				out.opt <-aggregate(na.omit(sim.u5dr.opt.base3.pop3.eth)[, 8:(runs+7)], list(na.omit(sim.u5dr.opt.base3.pop3.eth)$stratum), FUN=sum, na.rm=TRUE)				
				out.opt <- apply(out.opt[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } )
				out.opt <- round(out.opt/100, 0)*100
				out.pes <-aggregate(na.omit(sim.u5dr.pes.base3.pop3.eth)[, 8:(runs+7)], list(na.omit(sim.u5dr.pes.base3.pop3.eth)$stratum), FUN=sum, na.rm=TRUE)				
				out.pes <- apply(out.pes[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } )
				out.pes <- round(out.pes/100, 0)*100
				tab[, "base3.u5"] <- paste(out.opt, " to ", out.pes, sep="")

								
				tab[nrow(tab)+1, 1] <- NA
				
				out.opt <- round(quantile(colSums(na.omit(sim.cdr.opt.base1.pop3.eth)[, 8:(runs+7)]) , c(0.50)) / 100, 0) * 100 
				out.pes <- round(quantile(colSums(na.omit(sim.cdr.pes.base1.pop3.eth)[, 8:(runs+7)]) , c(0.50)) / 100, 0) * 100 
				tab[nrow(tab), "base1"] <- paste(out.opt, " to ", out.pes, sep="")

				out.opt <- round(quantile(colSums(na.omit(sim.u5dr.opt.base1.pop3.eth)[, 8:(runs+7)]) , c(0.50)) / 100, 0) * 100 
				out.pes <- round(quantile(colSums(na.omit(sim.u5dr.pes.base1.pop3.eth)[, 8:(runs+7)]) , c(0.50)) / 100, 0) * 100 
				tab[nrow(tab), "base1.u5"] <- paste(out.opt, " to ", out.pes, sep="")

				out.opt <- round(quantile(colSums(na.omit(sim.cdr.opt.base2.pop3.eth)[, 8:(runs+7)]) , c(0.50)) / 100, 0) * 100 
				out.pes <- round(quantile(colSums(na.omit(sim.cdr.pes.base2.pop3.eth)[, 8:(runs+7)]) , c(0.50)) / 100, 0) * 100 
				tab[nrow(tab), "base2"] <- paste(out.opt, " to ", out.pes, sep="")

				out.opt <- round(quantile(colSums(na.omit(sim.u5dr.opt.base2.pop3.eth)[, 8:(runs+7)]) , c(0.50)) / 100, 0) * 100 
				out.pes <- round(quantile(colSums(na.omit(sim.u5dr.pes.base2.pop3.eth)[, 8:(runs+7)]) , c(0.50)) / 100, 0) * 100 
				tab[nrow(tab), "base2.u5"] <- paste(out.opt, " to ", out.pes, sep="")

				out.opt <- round(quantile(colSums(na.omit(sim.cdr.opt.base3.pop3.eth)[, 8:(runs+7)]) , c(0.50)) / 100, 0) * 100 
				out.pes <- round(quantile(colSums(na.omit(sim.cdr.pes.base3.pop3.eth)[, 8:(runs+7)]) , c(0.50)) / 100, 0) * 100 
				tab[nrow(tab), "base3"] <- paste(out.opt, " to ", out.pes, sep="")

				out.opt <- round(quantile(colSums(na.omit(sim.u5dr.opt.base3.pop3.eth)[, 8:(runs+7)]) , c(0.50)) / 100, 0) * 100 
				out.pes <- round(quantile(colSums(na.omit(sim.u5dr.pes.base3.pop3.eth)[, 8:(runs+7)]) , c(0.50)) / 100, 0) * 100 
				tab[nrow(tab), "base3.u5"] <- paste(out.opt, " to ", out.pes, sep="")
				
				write.csv(tab, "Ethiopia_toll_stratum.pop3.csv", row.names=FALSE)
						

#.........................................................................................
### Kenya camps estimation

	runs <- 10000
	# Kenya
	tst.analysis.ken <- subset(tst, location=="Kenya" & tm > 51 & tm < 80)
	
		# simulation with optimistic scenario, baseline method 1, population dataset being analysed
		sim.cdr.opt.base1.pop3.ken <- replicate(runs, {
				(tst.analysis.ken[, "cdr_opt_1to2"]  - apply(tst.analysis.ken, 1, f.base1, base_tot, 5, "cdr") ) * tst.analysis.ken[, "pop3_1to2"] * 30.42 / 10000 +
				(tst.analysis.ken[, "cdr_opt_3to5"]  - apply(tst.analysis.ken, 1, f.base1, base_tot, 5, "cdr") ) * tst.analysis.ken[, "pop3_3to5"] * 30.42 / 10000 +
				(tst.analysis.ken[, "cdr_opt_6to11"]  - apply(tst.analysis.ken, 1, f.base1, base_tot, 5, "cdr") ) * tst.analysis.ken[, "pop3_6to11"] * 30.42 / 10000 +
				(tst.analysis.ken[, "cdr_opt_12plus"]  - apply(tst.analysis.ken, 1, f.base1, base_tot, 5, "cdr") ) * tst.analysis.ken[, "pop3_12plus"] * 30.42 / 10000
				} )	
		sim.cdr.opt.base1.pop3.ken <- cbind(tst.analysis.ken[, c("stratum", "region", "livelihood", "tm", "y", "m")] , sim.cdr.opt.base1.pop3.ken )	
		write.csv(sim.cdr.opt.base1.pop3.ken, "kenya_sim.cdr.opt.base1.pop3.csv")

		sim.u5dr.opt.base1.pop3.ken <- replicate(runs, {
				(tst.analysis.ken[, "u5dr_opt_1to2"]  - apply(tst.analysis.ken, 1, f.base1, base_tot, 5, "u5dr") ) * tst.analysis.ken[, "pop3_1to2"] * sample(prop.u5.ken, nrow(tst.analysis.ken), replace=TRUE) * 30.42 / 10000 +
				(tst.analysis.ken[, "u5dr_opt_3to5"]  - apply(tst.analysis.ken, 1, f.base1, base_tot, 5, "u5dr") ) * tst.analysis.ken[, "pop3_3to5"] * sample(prop.u5.ken, nrow(tst.analysis.ken), replace=TRUE) * 30.42 / 10000 +
				(tst.analysis.ken[, "u5dr_opt_6to11"]  - apply(tst.analysis.ken, 1, f.base1, base_tot, 5, "u5dr") ) * tst.analysis.ken[, "pop3_6to11"] * sample(prop.u5.ken, nrow(tst.analysis.ken), replace=TRUE) * 30.42 / 10000 +
				(tst.analysis.ken[, "u5dr_opt_12plus"]  - apply(tst.analysis.ken, 1, f.base1, base_tot, 5, "u5dr") ) * tst.analysis.ken[, "pop3_12plus"] * sample(prop.u5.ken, nrow(tst.analysis.ken), replace=TRUE) * 30.42 / 10000
				} )	
		sim.u5dr.opt.base1.pop3.ken <- cbind(tst.analysis.ken[, c("stratum", "region", "livelihood", "tm", "y", "m")] , sim.u5dr.opt.base1.pop3.ken )	
		write.csv(sim.u5dr.opt.base1.pop3.ken, "kenya_sim.u5dr.opt.base1.pop3.csv")

		# simulation with pessimistic scenario, baseline method 1, population dataset being analysed			
		sim.cdr.pes.base1.pop3.ken <- replicate(runs, {
				(tst.analysis.ken[, "cdr_pes_1to2"]  - apply(tst.analysis.ken, 1, f.base1, base_tot, 5, "cdr") ) * tst.analysis.ken[, "pop3_1to2"] * 30.42 / 10000 +
				(tst.analysis.ken[, "cdr_pes_3to5"]  - apply(tst.analysis.ken, 1, f.base1, base_tot, 5, "cdr") ) * tst.analysis.ken[, "pop3_3to5"] * 30.42 / 10000 +
				(tst.analysis.ken[, "cdr_pes_6to11"]  - apply(tst.analysis.ken, 1, f.base1, base_tot, 5, "cdr") ) * tst.analysis.ken[, "pop3_6to11"] * 30.42 / 10000 +
				(tst.analysis.ken[, "cdr_pes_12plus"]  - apply(tst.analysis.ken, 1, f.base1, base_tot, 5, "cdr") ) * tst.analysis.ken[, "pop3_12plus"] * 30.42 / 10000
				} )	
		sim.cdr.pes.base1.pop3.ken <- cbind(tst.analysis.ken[, c("stratum", "region", "livelihood", "tm", "y", "m")] , sim.cdr.pes.base1.pop3.ken )	
		write.csv(sim.cdr.pes.base1.pop3.ken, "kenya_sim.cdr.pes.base1.pop3.csv")

		sim.u5dr.pes.base1.pop3.ken <- replicate(runs, {
				(tst.analysis.ken[, "u5dr_pes_1to2"]  - apply(tst.analysis.ken, 1, f.base1, base_tot, 5, "u5dr") ) * tst.analysis.ken[, "pop3_1to2"] * sample(prop.u5.ken, nrow(tst.analysis.ken), replace=TRUE) * 30.42 / 10000 +
				(tst.analysis.ken[, "u5dr_pes_3to5"]  - apply(tst.analysis.ken, 1, f.base1, base_tot, 5, "u5dr") ) * tst.analysis.ken[, "pop3_3to5"] * sample(prop.u5.ken, nrow(tst.analysis.ken), replace=TRUE) * 30.42 / 10000 +
				(tst.analysis.ken[, "u5dr_pes_6to11"]  - apply(tst.analysis.ken, 1, f.base1, base_tot, 5, "u5dr") ) * tst.analysis.ken[, "pop3_6to11"] * sample(prop.u5.ken, nrow(tst.analysis.ken), replace=TRUE) * 30.42 / 10000 +
				(tst.analysis.ken[, "u5dr_pes_12plus"]  - apply(tst.analysis.ken, 1, f.base1, base_tot, 5, "u5dr") ) * tst.analysis.ken[, "pop3_12plus"] * sample(prop.u5.ken, nrow(tst.analysis.ken), replace=TRUE) * 30.42 / 10000
				} )	
		sim.u5dr.pes.base1.pop3.ken <- cbind(tst.analysis.ken[, c("stratum", "region", "livelihood", "tm", "y", "m")] , sim.u5dr.pes.base1.pop3.ken )	
		write.csv(sim.u5dr.pes.base1.pop3.ken, "kenya_sim.u5dr.pes.base1.pop3.csv")
	
		# ...
	
		# simulation with optimistic scenario, baseline method 2, population dataset being analysed
		sim.cdr.opt.base2.pop3.ken <- replicate(runs, {
				(tst.analysis.ken[, "cdr_opt_1to2"]  - replicate(nrow(tst.analysis.ken), {f.base2(base_ipc, "cdr") } ) ) * tst.analysis.ken[, "pop3_1to2"] * 30.42 / 10000 +
				(tst.analysis.ken[, "cdr_opt_3to5"]  - replicate(nrow(tst.analysis.ken), {f.base2(base_ipc, "cdr") } ) ) * tst.analysis.ken[, "pop3_3to5"] * 30.42 / 10000 +
				(tst.analysis.ken[, "cdr_opt_6to11"]  - replicate(nrow(tst.analysis.ken), {f.base2(base_ipc, "cdr") } ) ) * tst.analysis.ken[, "pop3_6to11"] * 30.42 / 10000 +
				(tst.analysis.ken[, "cdr_opt_12plus"]  - replicate(nrow(tst.analysis.ken), {f.base2(base_ipc, "cdr") } ) ) * tst.analysis.ken[, "pop3_12plus"] * 30.42 / 10000				
			} )	
		sim.cdr.opt.base2.pop3.ken <- cbind(tst.analysis.ken[, c("stratum", "region", "livelihood", "tm", "y", "m")] , sim.cdr.opt.base2.pop3.ken )	
		write.csv(sim.cdr.opt.base2.pop3.ken, "kenya_sim.cdr.opt.base2.pop3.csv")

		sim.u5dr.opt.base2.pop3.ken <- replicate(runs, {
				(tst.analysis.ken[, "u5dr_opt_1to2"]  - replicate(nrow(tst.analysis.ken), {f.base2(base_ipc, "u5dr") } ) ) * tst.analysis.ken[, "pop3_1to2"] * sample(prop.u5.ken, nrow(tst.analysis.ken), replace=TRUE) * 30.42 / 10000 +
				(tst.analysis.ken[, "u5dr_opt_3to5"]  - replicate(nrow(tst.analysis.ken), {f.base2(base_ipc, "u5dr") } ) ) * tst.analysis.ken[, "pop3_3to5"] * sample(prop.u5.ken, nrow(tst.analysis.ken), replace=TRUE) * 30.42 / 10000 +
				(tst.analysis.ken[, "u5dr_opt_6to11"]  - replicate(nrow(tst.analysis.ken), {f.base2(base_ipc, "u5dr") } ) ) * tst.analysis.ken[, "pop3_6to11"] * sample(prop.u5.ken, nrow(tst.analysis.ken), replace=TRUE) * 30.42 / 10000 +
				(tst.analysis.ken[, "u5dr_opt_12plus"]  - replicate(nrow(tst.analysis.ken), {f.base2(base_ipc, "u5dr") } ) ) * tst.analysis.ken[, "pop3_12plus"] * sample(prop.u5.ken, nrow(tst.analysis.ken), replace=TRUE) * 30.42 / 10000				
			} )	
		sim.u5dr.opt.base2.pop3.ken <- cbind(tst.analysis.ken[, c("stratum", "region", "livelihood", "tm", "y", "m")] , sim.u5dr.opt.base2.pop3.ken )	
		write.csv(sim.u5dr.opt.base2.pop3.ken, "kenya_sim.u5dr.opt.base2.pop3.csv")
			
		# simulation with pessimistic scenario, baseline method 2, population dataset being analysed			
		sim.cdr.pes.base2.pop3.ken <- replicate(runs, {
				(tst.analysis.ken[, "cdr_pes_1to2"]  - replicate(nrow(tst.analysis.ken), {f.base2(base_ipc, "cdr") } ) ) * tst.analysis.ken[, "pop3_1to2"] * 30.42 / 10000 +
				(tst.analysis.ken[, "cdr_pes_3to5"]  - replicate(nrow(tst.analysis.ken), {f.base2(base_ipc, "cdr") } ) ) * tst.analysis.ken[, "pop3_3to5"] * 30.42 / 10000 +
				(tst.analysis.ken[, "cdr_pes_6to11"]  - replicate(nrow(tst.analysis.ken), {f.base2(base_ipc, "cdr") } ) ) * tst.analysis.ken[, "pop3_6to11"] * 30.42 / 10000 +
				(tst.analysis.ken[, "cdr_pes_12plus"]  - replicate(nrow(tst.analysis.ken), {f.base2(base_ipc, "cdr") } ) ) * tst.analysis.ken[, "pop3_12plus"] * 30.42 / 10000				
			} )	
		sim.cdr.pes.base2.pop3.ken <- cbind(tst.analysis.ken[, c("stratum", "region", "livelihood", "tm", "y", "m")] , sim.cdr.pes.base2.pop3.ken )	
		write.csv(sim.cdr.pes.base2.pop3.ken, "kenya_sim.cdr.pes.base2.pop3.csv")

		sim.u5dr.pes.base2.pop3.ken <- replicate(runs, {
				(tst.analysis.ken[, "u5dr_pes_1to2"]  - replicate(nrow(tst.analysis.ken), {f.base2(base_ipc, "u5dr") } ) ) * tst.analysis.ken[, "pop3_1to2"] * sample(prop.u5.ken, nrow(tst.analysis.ken), replace=TRUE) * 30.42 / 10000 +
				(tst.analysis.ken[, "u5dr_pes_3to5"]  - replicate(nrow(tst.analysis.ken), {f.base2(base_ipc, "u5dr") } ) ) * tst.analysis.ken[, "pop3_3to5"] * sample(prop.u5.ken, nrow(tst.analysis.ken), replace=TRUE) * 30.42 / 10000 +
				(tst.analysis.ken[, "u5dr_pes_6to11"]  - replicate(nrow(tst.analysis.ken), {f.base2(base_ipc, "u5dr") } ) ) * tst.analysis.ken[, "pop3_6to11"] * sample(prop.u5.ken, nrow(tst.analysis.ken), replace=TRUE) * 30.42 / 10000 +
				(tst.analysis.ken[, "u5dr_pes_12plus"]  - replicate(nrow(tst.analysis.ken), {f.base2(base_ipc, "u5dr") } ) ) * tst.analysis.ken[, "pop3_12plus"] * sample(prop.u5.ken, nrow(tst.analysis.ken), replace=TRUE) * 30.42 / 10000				
			} )	
		sim.u5dr.pes.base2.pop3.ken <- cbind(tst.analysis.ken[, c("stratum", "region", "livelihood", "tm", "y", "m")] , sim.u5dr.pes.base2.pop3.ken )	
		write.csv(sim.u5dr.pes.base2.pop3.ken, "kenya_sim.u5dr.pes.base2.pop3.csv")
			
		# ...

		# simulation with optimistic scenario, baseline mkenod 3, population dataset being analysed
		sim.cdr.opt.base3.pop3.ken <- replicate(runs, {
				x <- apply(tst.analysis.ken, 1, f.base3.ken, "cdr", tst.analysis.som, dat, lambda, f.bctback)
				y <- (tst.analysis.ken[, "cdr_opt_1to2"]  - x ) * tst.analysis.ken[, "pop3_1to2"] * 30.42 / 10000 +
				     (tst.analysis.ken[, "cdr_opt_3to5"]  - x ) * tst.analysis.ken[, "pop3_3to5"] * 30.42 / 10000 +
				     (tst.analysis.ken[, "cdr_opt_6to11"]  - x ) * tst.analysis.ken[, "pop3_6to11"] * 30.42 / 10000 +
				     (tst.analysis.ken[, "cdr_opt_12plus"]  - x ) * tst.analysis.ken[, "pop3_12plus"] * 30.42 / 10000
				return(y)
			} )	
		sim.cdr.opt.base3.pop3.ken <- cbind(tst.analysis.ken[, c("stratum", "region", "livelihood", "tm", "y", "m")] , sim.cdr.opt.base3.pop3.ken )	
		write.csv(sim.cdr.opt.base3.pop3.ken, "kenya_sim.cdr.opt.base3.pop3.csv")

		sim.u5dr.opt.base3.pop3.ken <- replicate(runs, {
				x <- apply(tst.analysis.ken, 1, f.base3.ken, "u5dr", tst.analysis.som, dat, lambda, f.bctback)
				y <- (tst.analysis.ken[, "u5dr_opt_1to2"]  - x ) * tst.analysis.ken[, "pop3_1to2"] * sample(prop.u5.ken, nrow(tst.analysis.ken), replace=TRUE) * 30.42 / 10000 +
				     (tst.analysis.ken[, "u5dr_opt_3to5"]  - x ) * tst.analysis.ken[, "pop3_3to5"] * sample(prop.u5.ken, nrow(tst.analysis.ken), replace=TRUE) * 30.42 / 10000 +
				     (tst.analysis.ken[, "u5dr_opt_6to11"]  - x ) * tst.analysis.ken[, "pop3_6to11"] * sample(prop.u5.ken, nrow(tst.analysis.ken), replace=TRUE) * 30.42 / 10000 +
				     (tst.analysis.ken[, "u5dr_opt_12plus"]  - x ) * tst.analysis.ken[, "pop3_12plus"] * sample(prop.u5.ken, nrow(tst.analysis.ken), replace=TRUE) * 30.42 / 10000
				return(y)
			} )	
		sim.u5dr.opt.base3.pop3.ken <- cbind(tst.analysis.ken[, c("stratum", "region", "livelihood", "tm", "y", "m")] , sim.u5dr.opt.base3.pop3.ken )	
		write.csv(sim.u5dr.opt.base3.pop3.ken, "kenya_sim.u5dr.opt.base3.pop3.csv")

		# simulation with pessimistic scenario, baseline method 3, population dataset being analysed			

		sim.cdr.pes.base3.pop3.ken <- replicate(runs, {
				x <- apply(tst.analysis.ken, 1, f.base3.ken, "cdr", tst.analysis.som, dat, lambda, f.bctback)
				y <- (tst.analysis.ken[, "cdr_pes_1to2"]  - x ) * tst.analysis.ken[, "pop3_1to2"] * 30.42 / 10000 +
				     (tst.analysis.ken[, "cdr_pes_3to5"]  - x ) * tst.analysis.ken[, "pop3_3to5"] * 30.42 / 10000 +
				     (tst.analysis.ken[, "cdr_pes_6to11"]  - x ) * tst.analysis.ken[, "pop3_6to11"] * 30.42 / 10000 +
				     (tst.analysis.ken[, "cdr_pes_12plus"]  - x ) * tst.analysis.ken[, "pop3_12plus"] * 30.42 / 10000
				return(y)
			} )	
		sim.cdr.pes.base3.pop3.ken <- cbind(tst.analysis.ken[, c("stratum", "region", "livelihood", "tm", "y", "m")] , sim.cdr.pes.base3.pop3.ken )	
		write.csv(sim.cdr.pes.base3.pop3.ken, "kenya_sim.cdr.pes.base3.pop3.csv")

		sim.u5dr.pes.base3.pop3.ken <- replicate(runs, {
				x <- apply(tst.analysis.ken, 1, f.base3.ken, "u5dr", tst.analysis.som, dat, lambda, f.bctback)
				y <- (tst.analysis.ken[, "u5dr_pes_1to2"]  - x ) * tst.analysis.ken[, "pop3_1to2"] * sample(prop.u5.ken, nrow(tst.analysis.ken), replace=TRUE) * 30.42 / 10000 +
				     (tst.analysis.ken[, "u5dr_pes_3to5"]  - x ) * tst.analysis.ken[, "pop3_3to5"] * sample(prop.u5.ken, nrow(tst.analysis.ken), replace=TRUE) * 30.42 / 10000 +
				     (tst.analysis.ken[, "u5dr_pes_6to11"]  - x ) * tst.analysis.ken[, "pop3_6to11"] * sample(prop.u5.ken, nrow(tst.analysis.ken), replace=TRUE) * 30.42 / 10000 +
				     (tst.analysis.ken[, "u5dr_pes_12plus"]  - x ) * tst.analysis.ken[, "pop3_12plus"] * sample(prop.u5.ken, nrow(tst.analysis.ken), replace=TRUE) * 30.42 / 10000
				return(y)
			} )	
		sim.u5dr.pes.base3.pop3.ken <- cbind(tst.analysis.ken[, c("stratum", "region", "livelihood", "tm", "y", "m")] , sim.u5dr.pes.base3.pop3.ken )	
		write.csv(sim.u5dr.pes.base3.pop3.ken, "kenya_sim.u5dr.pes.base3.pop3.csv")	
	
	
		# analysis
	
			# create result tables

				# by stratum
				tab <- data.frame(unique(na.omit(sim.cdr.opt.base1.pop3.ken)[, c("region", "livelihood")]))
				
				out.opt <-aggregate(na.omit(sim.cdr.opt.base1.pop3.ken)[, 7:(runs+6)], list(na.omit(sim.cdr.opt.base1.pop3.ken)$stratum), FUN=sum, na.rm=TRUE)				
				out.opt <- apply(out.opt[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } )
				out.opt <- round(out.opt/100, 0)*100
				out.pes <-aggregate(na.omit(sim.cdr.pes.base1.pop3.ken)[, 7:(runs+6)], list(na.omit(sim.cdr.pes.base1.pop3.ken)$stratum), FUN=sum, na.rm=TRUE)				
				out.pes <- apply(out.pes[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } )
				out.pes <- round(out.pes/100, 0)*100
				tab[, "base1"] <- paste(out.opt, " to ", out.pes, sep="")

				out.opt <-aggregate(na.omit(sim.u5dr.opt.base1.pop3.ken)[, 7:(runs+6)], list(na.omit(sim.u5dr.opt.base1.pop3.ken)$stratum), FUN=sum, na.rm=TRUE)				
				out.opt <- apply(out.opt[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } )
				out.opt <- round(out.opt/100, 0)*100
				out.pes <-aggregate(na.omit(sim.u5dr.pes.base1.pop3.ken)[, 7:(runs+6)], list(na.omit(sim.u5dr.pes.base1.pop3.ken)$stratum), FUN=sum, na.rm=TRUE)				
				out.pes <- apply(out.pes[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } )
				out.pes <- round(out.pes/100, 0)*100
				tab[, "base1.u5"] <- paste(out.opt, " to ", out.pes, sep="")
				
				out.opt <-aggregate(na.omit(sim.cdr.opt.base2.pop3.ken)[, 7:(runs+6)], list(na.omit(sim.cdr.opt.base2.pop3.ken)$stratum), FUN=sum, na.rm=TRUE)				
				out.opt <- apply(out.opt[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } )
				out.opt <- round(out.opt/100, 0)*100
				out.pes <-aggregate(na.omit(sim.cdr.pes.base2.pop3.ken)[, 7:(runs+6)], list(na.omit(sim.cdr.pes.base2.pop3.ken)$stratum), FUN=sum, na.rm=TRUE)				
				out.pes <- apply(out.pes[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } )
				out.pes <- round(out.pes/100, 0)*100
				tab[, "base2"] <- paste(out.opt, " to ", out.pes, sep="")

				out.opt <-aggregate(na.omit(sim.u5dr.opt.base2.pop3.ken)[, 7:(runs+6)], list(na.omit(sim.u5dr.opt.base2.pop3.ken)$stratum), FUN=sum, na.rm=TRUE)				
				out.opt <- apply(out.opt[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } )
				out.opt <- round(out.opt/100, 0)*100
				out.pes <-aggregate(na.omit(sim.u5dr.pes.base2.pop3.ken)[, 7:(runs+6)], list(na.omit(sim.u5dr.pes.base2.pop3.ken)$stratum), FUN=sum, na.rm=TRUE)				
				out.pes <- apply(out.pes[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } )
				out.pes <- round(out.pes/100, 0)*100
				tab[, "base2.u5"] <- paste(out.opt, " to ", out.pes, sep="")

				out.opt <-aggregate(na.omit(sim.cdr.opt.base3.pop3.ken)[, 7:(runs+6)], list(na.omit(sim.cdr.opt.base3.pop3.ken)$stratum), FUN=sum, na.rm=TRUE)				
				out.opt <- apply(out.opt[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } )
				out.opt <- round(out.opt/100, 0)*100
				out.pes <-aggregate(na.omit(sim.cdr.pes.base3.pop3.ken)[, 7:(runs+6)], list(na.omit(sim.cdr.pes.base3.pop3.ken)$stratum), FUN=sum, na.rm=TRUE)				
				out.pes <- apply(out.pes[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } )
				out.pes <- round(out.pes/100, 0)*100
				tab[, "base3"] <- paste(out.opt, " to ", out.pes, sep="")

				out.opt <-aggregate(na.omit(sim.u5dr.opt.base3.pop3.ken)[, 7:(runs+6)], list(na.omit(sim.u5dr.opt.base3.pop3.ken)$stratum), FUN=sum, na.rm=TRUE)				
				out.opt <- apply(out.opt[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } )
				out.opt <- round(out.opt/100, 0)*100
				out.pes <-aggregate(na.omit(sim.u5dr.pes.base3.pop3.ken)[, 7:(runs+6)], list(na.omit(sim.u5dr.pes.base3.pop3.ken)$stratum), FUN=sum, na.rm=TRUE)				
				out.pes <- apply(out.pes[, -1], 1, function(x) {return(quantile(x, c(0.50)) ) } )
				out.pes <- round(out.pes/100, 0)*100
				tab[, "base3.u5"] <- paste(out.opt, " to ", out.pes, sep="")

								
				tab[nrow(tab)+1, 1] <- NA
				
				out.opt <- round(quantile(colSums(na.omit(sim.cdr.opt.base1.pop3.ken)[, 7:(runs+6)]) , c(0.50)) / 100, 0) * 100 
				out.pes <- round(quantile(colSums(na.omit(sim.cdr.pes.base1.pop3.ken)[, 7:(runs+6)]) , c(0.50)) / 100, 0) * 100 
				tab[nrow(tab), "base1"] <- paste(out.opt, " to ", out.pes, sep="")

				out.opt <- round(quantile(colSums(na.omit(sim.u5dr.opt.base1.pop3.ken)[, 7:(runs+6)]) , c(0.50)) / 100, 0) * 100 
				out.pes <- round(quantile(colSums(na.omit(sim.u5dr.pes.base1.pop3.ken)[, 7:(runs+6)]) , c(0.50)) / 100, 0) * 100 
				tab[nrow(tab), "base1.u5"] <- paste(out.opt, " to ", out.pes, sep="")

				out.opt <- round(quantile(colSums(na.omit(sim.cdr.opt.base2.pop3.ken)[, 7:(runs+6)]) , c(0.50)) / 100, 0) * 100 
				out.pes <- round(quantile(colSums(na.omit(sim.cdr.pes.base2.pop3.ken)[, 7:(runs+6)]) , c(0.50)) / 100, 0) * 100 
				tab[nrow(tab), "base2"] <- paste(out.opt, " to ", out.pes, sep="")

				out.opt <- round(quantile(colSums(na.omit(sim.u5dr.opt.base2.pop3.ken)[, 7:(runs+6)]) , c(0.50)) / 100, 0) * 100 
				out.pes <- round(quantile(colSums(na.omit(sim.u5dr.pes.base2.pop3.ken)[, 7:(runs+6)]) , c(0.50)) / 100, 0) * 100 
				tab[nrow(tab), "base2.u5"] <- paste(out.opt, " to ", out.pes, sep="")

				out.opt <- round(quantile(colSums(na.omit(sim.cdr.opt.base3.pop3.ken)[, 7:(runs+6)]) , c(0.50)) / 100, 0) * 100 
				out.pes <- round(quantile(colSums(na.omit(sim.cdr.pes.base3.pop3.ken)[, 7:(runs+6)]) , c(0.50)) / 100, 0) * 100 
				tab[nrow(tab), "base3"] <- paste(out.opt, " to ", out.pes, sep="")

				out.opt <- round(quantile(colSums(na.omit(sim.u5dr.opt.base3.pop3.ken)[, 7:(runs+6)]) , c(0.50)) / 100, 0) * 100 
				out.pes <- round(quantile(colSums(na.omit(sim.u5dr.pes.base3.pop3.ken)[, 7:(runs+6)]) , c(0.50)) / 100, 0) * 100 
				tab[nrow(tab), "base3.u5"] <- paste(out.opt, " to ", out.pes, sep="")
				
				write.csv(tab, "Kenya_toll_stratum.pop3.csv", row.names=FALSE)
						







		